<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage  Workart Pro
 * @since  Workart Pro 1.0.0
 */

if ( ! function_exists( 'workart_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since  Workart Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function workart_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'workart_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'workart_pro_is_topbar_section_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since  Workart Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function workart_pro_is_topbar_section_enable( $control ) {
		return $control->manager->get_setting( 'workart_pro_theme_options[topbar_section_enable]' )->value();
	}
endif;

if ( ! function_exists( 'workart_pro_is_static_homepage_enable' ) ) :
	/**
	 * Check if static homepage is enabled.
	 *
	 * @since Workart Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function workart_pro_is_static_homepage_enable( $control ) {
		return ( 'page' == $control->manager->get_setting( 'show_on_front' )->value() );
	}
endif;

if ( ! function_exists( 'workart_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since  Workart Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function workart_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'workart_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'workart_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since  Workart Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function workart_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'workart_pro_theme_options[pagination_enable]' )->value();
	}
endif;

/**
 * Check if slider section is enabled.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_featured_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'workart_pro_theme_options[featured_slider_section_enable]' )->value() );
}

/**
 * Check if slider section content type is post.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_featured_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[featured_slider_content_type]' )->value();
	return workart_pro_is_featured_slider_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if slider section content type is page.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_featured_slider_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[featured_slider_content_type]' )->value();
	return workart_pro_is_featured_slider_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if slider section content type is category.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_featured_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[featured_slider_content_type]' )->value();
	return workart_pro_is_featured_slider_section_enable( $control ) && ( 'category' == $content_type );
}
/**
 * Check if slider separator section is enabled.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_featured_slider_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'workart_pro_theme_options[featured_slider_content_type]' )->value();
    return workart_pro_is_featured_slider_section_enable( $control ) && !( 'category' == $content_type );
}

/**
 * Check if hero slider section is enabled.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_hero_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'workart_pro_theme_options[hero_slider_section_enable]' )->value() );
}

/**
 * Check if hero slider section content type is post.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_hero_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[hero_slider_content_type]' )->value();
	return workart_pro_is_hero_slider_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if hero slider section content type is page.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_hero_slider_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[hero_slider_content_type]' )->value();
	return workart_pro_is_hero_slider_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if hero slider section content type is category.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_hero_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[hero_slider_content_type]' )->value();
	return workart_pro_is_hero_slider_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if hero slider section content type is product.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_hero_slider_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[hero_slider_content_type]' )->value();
	return workart_pro_is_hero_slider_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if hero slider section content type is product category.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_hero_slider_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[hero_slider_content_type]' )->value();
	return workart_pro_is_hero_slider_section_enable( $control ) && ( 'product-category' == $content_type );
}
/**
 * Check if hero slider separator section is enabled.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_hero_slider_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'workart_pro_theme_options[hero_slider_content_type]' )->value();
    return workart_pro_is_hero_slider_section_enable( $control ) && !( 'category' == $content_type || 'product-category' == $content_type );
}
/**
 * Check if about section is enabled.
 *
 * @since Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_about_us_section_enable( $control ) {
	return ( $control->manager->get_setting( 'workart_pro_theme_options[about_us_section_enable]' )->value() );
}

/**
 * Check if about section content type is page.
 *
 * @since Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_about_us_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[about_us_content_type]' )->value();
	return workart_pro_is_about_us_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if about section content type is post.
 *
 * @since Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_about_us_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[about_us_content_type]' )->value();
	return workart_pro_is_about_us_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if about section content type is custom.
 *
 * @since Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_about_us_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[about_us_content_type]' )->value();
	return workart_pro_is_about_us_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if about section content type is custom.
 *
 * @since Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_if_about_us_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[about_us_content_type]' )->value();
	return workart_pro_is_about_us_section_enable( $control ) && ( 'custom' == $content_type );
}
/**
 * Check if service section is enabled.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_our_services_section_enable( $control ) {
	return ( $control->manager->get_setting( 'workart_pro_theme_options[our_services_section_enable]' )->value() );
}

/**
 * Check if service section content type is page.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_our_services_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[our_services_content_type]' )->value();
	return workart_pro_is_our_services_section_enable( $control ) && ( 'page' == $content_type );
}
/**
 * Check if service section content type is post.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_our_services_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[our_services_content_type]' )->value();
	return workart_pro_is_our_services_section_enable( $control ) && ( 'post' == $content_type );
}
/**
 * Check if service section content type is category.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_our_services_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[our_services_content_type]' )->value();
	return workart_pro_is_our_services_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if Call To Action section is enabled.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_call_to_action_section_enable( $control ) {
	return ( $control->manager->get_setting( 'workart_pro_theme_options[call_to_action_section_enable]' )->value() );
}

/**
 * Check if Call To Action section is enabled.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_call_to_action_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[call_to_action_content_type]' )->value();
	return ( $control->manager->get_setting( 'workart_pro_theme_options[call_to_action_section_enable]' )->value() && ('post' == $content_type) );
}
/**
 * Check if Call To Action section is enabled.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_call_to_action_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[call_to_action_content_type]' )->value();
	return ( $control->manager->get_setting( 'workart_pro_theme_options[call_to_action_section_enable]' )->value() && ('page' == $content_type) );
}

/**
 * Check if Call To Action section is enabled.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_if_call_to_action_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[call_to_action_content_type]' )->value();
	return ( $control->manager->get_setting( 'workart_pro_theme_options[call_to_action_section_enable]' )->value() && ('custom' == $content_type) );
}

/**

 * Check if testimonial section is enabled.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_testimonial_section_enable( $control ) {
    return ( $control->manager->get_setting( 'workart_pro_theme_options[testimonial_section_enable]' )->value() );
}
/**
 * Check if testimonial section content type is page.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_testimonial_section_content_page_enable( $control ) {
    $content_type = $control->manager->get_setting( 'workart_pro_theme_options[testimonial_content_type]' )->value();
    return workart_pro_is_testimonial_section_enable( $control ) && ( 'page' == $content_type );
}
/**
 * Check if testimonial section content type is post.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_testimonial_section_content_post_enable( $control ) {
    $content_type = $control->manager->get_setting( 'workart_pro_theme_options[testimonial_content_type]' )->value();
    return workart_pro_is_testimonial_section_enable( $control ) && ( 'post' == $content_type );
}
/**
 * Check if testimonial section content type is category.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_testimonial_section_content_category_enable( $control ) {
    $content_type = $control->manager->get_setting( 'workart_pro_theme_options[testimonial_content_type]' )->value();
    return workart_pro_is_testimonial_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if gallery section is enabled.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_gallery_section_enable( $control ) {
	return ( $control->manager->get_setting( 'workart_pro_theme_options[gallery_section_enable]' )->value() );
}

/**
 * Check if gallery section content type is post.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_gallery_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[gallery_content_type]' )->value();
	return workart_pro_is_gallery_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if gallery section content type is page.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_gallery_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[gallery_content_type]' )->value();
	return workart_pro_is_gallery_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if gallery section content type is category.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_gallery_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[gallery_content_type]' )->value();
	return workart_pro_is_gallery_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if gallery section content type is recent.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_gallery_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[gallery_content_type]' )->value();
	return workart_pro_is_gallery_section_enable( $control ) && ( 'recent' == $content_type );
}
/**
 * Check if gallery separator section is enabled.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_gallery_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'workart_pro_theme_options[gallery_content_type]' )->value();
    return workart_pro_is_gallery_section_enable( $control ) && !( 'recent' == $content_type || 'category' == $content_type ) ;
}

/**
 * Check if popular_posts section is enabled.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_popular_posts_section_enable( $control ) {
	return ( $control->manager->get_setting( 'workart_pro_theme_options[popular_posts_section_enable]' )->value() );
}

/**
 * Check if popular_posts section content type is post.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_popular_posts_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[popular_posts_content_type]' )->value();
	return workart_pro_is_popular_posts_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if popular_posts section content type is page.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_popular_posts_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[popular_posts_content_type]' )->value();
	return workart_pro_is_popular_posts_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if popular_posts section content type is category.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_popular_posts_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[popular_posts_content_type]' )->value();
	return workart_pro_is_popular_posts_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if popular_posts section content type is recent.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_popular_posts_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[popular_posts_content_type]' )->value();
	return workart_pro_is_popular_posts_section_enable( $control ) && ( 'recent' == $content_type );
}
/**
 * Check if popular_posts separator section is enabled.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_popular_posts_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'workart_pro_theme_options[popular_posts_content_type]' )->value();
    return workart_pro_is_popular_posts_section_enable( $control ) && !( 'recent' == $content_type || 'category' == $content_type ) ;
}

/**
 * Check if featured_post section is enabled.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_featured_posts_section_enable( $control ) {
	return ( $control->manager->get_setting( 'workart_pro_theme_options[featured_posts_section_enable]' )->value() );
}

/**
 * Check if featured_post section content type is post.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_featured_posts_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[featured_posts_content_type]' )->value();
	return workart_pro_is_featured_posts_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if featured_post section content type is page.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_featured_posts_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[featured_posts_content_type]' )->value();
	return workart_pro_is_featured_posts_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if featured_post section content type is category.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_featured_posts_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[featured_posts_content_type]' )->value();
	return workart_pro_is_featured_posts_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if featured_post separator section is enabled.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_featured_posts_section_content_seperator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'workart_pro_theme_options[featured_posts_content_type]' )->value();
    return workart_pro_is_featured_posts_section_enable( $control ) && !( 'category' == $content_type ) ;
}

/**
 * Check if recent_posts section is enabled.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_recent_posts_section_enable( $control ) {
	return ( $control->manager->get_setting( 'workart_pro_theme_options[recent_posts_section_enable]' )->value() );
}

/**
 * Check if recent_posts section content type is post.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_recent_posts_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[recent_posts_content_type]' )->value();
	return workart_pro_is_recent_posts_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if recent_posts section content type is page.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_recent_posts_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[recent_posts_content_type]' )->value();
	return workart_pro_is_recent_posts_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if recent_posts section content type is category.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_recent_posts_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[recent_posts_content_type]' )->value();
	return workart_pro_is_recent_posts_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if recent_posts section content type is recent.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_recent_posts_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[recent_posts_content_type]' )->value();
	return workart_pro_is_recent_posts_section_enable( $control ) && ( 'recent' == $content_type );
}
/**
 * Check if recent_posts separator section is enabled.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_recent_posts_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'workart_pro_theme_options[recent_posts_content_type]' )->value();
    return workart_pro_is_recent_posts_section_enable( $control ) && !( 'recent' == $content_type || 'category' == $content_type ) ;
}


/**
 * Check if subscribe section is enabled.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_subscribe_section_enable( $control ) {
	return ( $control->manager->get_setting( 'workart_pro_theme_options[subscribe_section_enable]' )->value() );
}

/**
 * Check if featured_products section is enabled.
 *
 * @since Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_featured_products_section_enable( $control ) {
	return ( $control->manager->get_setting( 'workart_pro_theme_options[featured_products_section_enable]' )->value() );
}

/**
 * Check if featured_products section content type is product.
 *
 * @since Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_featured_products_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[featured_products_content_type]' )->value();
	return workart_pro_is_featured_products_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if featured_products section content type is post.
 *
 * @since Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_featured_products_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[featured_products_content_type]' )->value();
	return workart_pro_is_featured_products_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if featured_products section content type is product-category.
 *
 * @since Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_featured_products_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[featured_products_content_type]' )->value();
	return workart_pro_is_featured_products_section_enable( $control ) && ( 'product-category' == $content_type );
}

/**
 * Check if featured_artist section is enabled.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_featured_artist_section_enable( $control ) {
	return ( $control->manager->get_setting( 'workart_pro_theme_options[featured_artist_section_enable]' )->value() );
}

/**
 * Check if featured_artist section content type is post.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_featured_artist_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[featured_artist_content_type]' )->value();
	return workart_pro_is_featured_artist_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if featured_artist section content type is page.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_featured_artist_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[featured_artist_content_type]' )->value();
	return workart_pro_is_featured_artist_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if featured_artist section content type is category.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_featured_artist_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[featured_artist_content_type]' )->value();
	return workart_pro_is_featured_artist_section_enable( $control ) && ( 'category' == $content_type );
}
/**
 * Check if featured_artist separator section is enabled.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_featured_artist_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'workart_pro_theme_options[featured_artist_content_type]' )->value();
    return workart_pro_is_featured_artist_section_enable( $control ) && !( 'category' == $content_type );
}

/**
 * Check if magazine_popular_posts section is enabled.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_magazine_popular_posts_section_enable( $control ) {
	return ( $control->manager->get_setting( 'workart_pro_theme_options[magazine_popular_posts_section_enable]' )->value() );
}

/**
 * Check if magazine_popular_posts section content type is post.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_magazine_popular_posts_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[magazine_popular_posts_content_type]' )->value();
	return workart_pro_is_magazine_popular_posts_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if magazine_popular_posts section content type is page.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_magazine_popular_posts_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[magazine_popular_posts_content_type]' )->value();
	return workart_pro_is_magazine_popular_posts_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if magazine_popular_posts section content type is category.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_magazine_popular_posts_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[magazine_popular_posts_content_type]' )->value();
	return workart_pro_is_magazine_popular_posts_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if magazine_popular_posts section content type is recent.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_magazine_popular_posts_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[magazine_popular_posts_content_type]' )->value();
	return workart_pro_is_magazine_popular_posts_section_enable( $control ) && ( 'recent' == $content_type );
}
/**
 * Check if magazine_popular_posts separator section is enabled.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_magazine_popular_posts_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'workart_pro_theme_options[magazine_popular_posts_content_type]' )->value();
    return workart_pro_is_magazine_popular_posts_section_enable( $control ) && !( 'recent' == $content_type || 'category' == $content_type ) ;
}

/**
 * Check if latest_post section is enabled.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_latest_posts_section_enable( $control ) {
	return ( $control->manager->get_setting( 'workart_pro_theme_options[latest_posts_section_enable]' )->value() );
}

/**
 * Check if latest_post section content type is post.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_latest_posts_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[latest_posts_content_type]' )->value();
	return workart_pro_is_latest_posts_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if latest_post section content type is page.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_latest_posts_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[latest_posts_content_type]' )->value();
	return workart_pro_is_latest_posts_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if latest_post section content type is category.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_latest_posts_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[latest_posts_content_type]' )->value();
	return workart_pro_is_latest_posts_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if latest_post section content type is recent.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_latest_posts_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[latest_posts_content_type]' )->value();
	return workart_pro_is_latest_posts_section_enable( $control ) && ( 'recent' == $content_type );
}
/**
 * Check if latest_post separator section is enabled.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_latest_posts_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'workart_pro_theme_options[latest_posts_content_type]' )->value();
    return workart_pro_is_latest_posts_section_enable( $control ) && !( 'recent' == $content_type || 'category' == $content_type ) ;
}

/**
 * Check if section is enabled in pro design.
 *
 * @since Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_pro_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'workart_pro_theme_options[home_layout]' )->value();
	return ( $home_layout == 'pro-design' ||  $home_layout == 'default-design');
}

/**
 * Check if popular_product section is enabled.
 *
 * @since Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_popular_products_section_enable( $control ) {
	return ( $control->manager->get_setting( 'workart_pro_theme_options[popular_products_section_enable]' )->value() );
}

/**
 * Check if popular_product section content type is category.
 *
 * @since Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_popular_products_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[popular_products_content_type]' )->value();
	return workart_pro_is_popular_products_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if popular_product section content type is product-category.
 *
 * @since Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_popular_products_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[popular_products_content_type]' )->value();
	return workart_pro_is_popular_products_section_enable( $control ) && ( 'product-category' == $content_type );
}


/**
 * Check if popular_product section separator is enabled.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_popular_products_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'workart_pro_theme_options[popular_products_content_type]' )->value();
    return workart_pro_is_popular_products_section_enable( $control ) && !( 'product-category' == $content_type );
}

/**
 * Check if recent_product section is enabled.
 *
 * @since Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_recent_products_section_enable( $control ) {
	return ( $control->manager->get_setting( 'workart_pro_theme_options[recent_products_section_enable]' )->value() );
}

/**
 * Check if recent_product section content type is product.
 *
 * @since Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_recent_products_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[recent_products_content_type]' )->value();
	return workart_pro_is_recent_products_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if recent_product section content type is product-category.
 *
 * @since Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_recent_products_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[recent_products_content_type]' )->value();
	return workart_pro_is_recent_products_section_enable( $control ) && ( 'product-category' == $content_type );
}

/**
 * Check if recent_product section separator is enable
 *
 * @since Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_recent_products_section_separator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[recent_products_content_type]' )->value();
	return workart_pro_is_recent_products_section_enable( $control ) && !( 'product-category' == $content_type );
}

/**
 * Check if our_partners section is enabled.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_our_partners_section_enable( $control ) {
	return ( $control->manager->get_setting( 'workart_pro_theme_options[our_partners_section_enable]' )->value() );
}

/**
 * Check if our_partners section content type is post.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_our_partners_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[our_partners_content_type]' )->value();
	return workart_pro_is_our_partners_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if our_partners section content type is page.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_our_partners_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[our_partners_content_type]' )->value();
	return workart_pro_is_our_partners_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if our_partners section content type is custom.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_our_partners_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[our_partners_content_type]' )->value();
	return workart_pro_is_our_partners_section_enable( $control ) && ( 'custom' == $content_type );
}
/**
 * Check if our_partners section content type is category.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_our_partners_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[our_partners_content_type]' )->value();
	return workart_pro_is_our_partners_section_enable( $control ) && ( 'category' == $content_type );
}
/**
 * Check if our_partners separator section is enabled.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_our_partners_section_separator_enable( $control ) {

    $content_type = $control->manager->get_setting( 'workart_pro_theme_options[our_partners_content_type]' )->value();
    return workart_pro_is_our_partners_section_enable( $control ) && !( 'category' == $content_type );
}

/**
 * Check if trending_products section is enabled.
 *
 * @since Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_trending_products_section_enable( $control ) {
	return ( $control->manager->get_setting( 'workart_pro_theme_options[trending_products_section_enable]' )->value() );
}

/**
 * Check if trending_products section content type is product.
 *
 * @since Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_trending_products_section_content_product_enable_1( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[trending_products_content_type_1]' )->value();
	return workart_pro_is_trending_products_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if trending_products section content type is product-category.
 *
 * @since Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_trending_products_section_content_product_category_enable_1( $control ) {
	
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[trending_products_content_type_1]' )->value();
	return workart_pro_is_trending_products_section_enable( $control ) && ( 'product-category' == $content_type );
}

/**
 * Check if trending_products section content type is product.
 *
 * @since Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_trending_products_section_content_product_enable_2( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[trending_products_content_type_2]' )->value();
	return workart_pro_is_trending_products_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if trending_products section content type is product-category.
 *
 * @since Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_trending_products_section_content_product_category_enable_2( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[trending_products_content_type_2]' )->value();
	return workart_pro_is_trending_products_section_enable( $control ) && ( 'product-category' == $content_type );
}

/**
 * Check if trending_products section content type is product.
 *
 * @since Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_trending_products_section_content_product_enable_3( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[trending_products_content_type_3]' )->value();
	return workart_pro_is_trending_products_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if trending_products section content type is product-category.
 *
 * @since Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_trending_products_section_content_product_category_enable_3( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[trending_products_content_type_3]' )->value();
	return workart_pro_is_trending_products_section_enable( $control ) && ( 'product-category' == $content_type );
}

/**
 * Check if trending_products section separator is enabled.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_trending_products_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'workart_pro_theme_options[trending_products_content_type]' )->value();
    return workart_pro_is_trending_products_section_enable( $control ) && !( 'product-category' == $content_type );
}

/**
 * Check if products_collection section is enabled.
 *
 * @since Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_products_collection_section_enable( $control ) {
	return ( $control->manager->get_setting( 'workart_pro_theme_options[products_collection_section_enable]' )->value() );
}

/**
 * Check if products_collection section content type is product.
 *
 * @since Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_products_collection_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[products_collection_content_type]' )->value();
	return workart_pro_is_products_collection_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if products_collection section content type is page.
 *
 * @since Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_products_collection_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[products_collection_content_type]' )->value();
	return workart_pro_is_products_collection_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if products_collection section content type is post.
 *
 * @since Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_products_collection_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[products_collection_content_type]' )->value();
	return workart_pro_is_products_collection_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if products_collection section content type is product-category.
 *
 * @since Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_products_collection_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[products_collection_content_type]' )->value();
	return workart_pro_is_products_collection_section_enable( $control ) && ( 'product-category' == $content_type );
}

/**
 * Check if products_collection section separator is enabled.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_products_collection_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'workart_pro_theme_options[products_collection_content_type]' )->value();
    return workart_pro_is_products_collection_section_enable( $control ) && !( 'product-category' == $content_type );
}

/**
 * Check if latest_products section is enabled.
 *
 * @since Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_latest_products_section_enable( $control ) {
	return ( $control->manager->get_setting( 'workart_pro_theme_options[latest_products_section_enable]' )->value() );
}

/**
 * Check if latest_products section content type is product.
 *
 * @since Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_latest_products_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[latest_products_content_type]' )->value();
	return workart_pro_is_latest_products_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if latest_products section content type is product-category.
 *
 * @since Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_latest_products_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'workart_pro_theme_options[latest_products_content_type]' )->value();
	return workart_pro_is_latest_products_section_enable( $control ) && ( 'product-category' == $content_type );
}


/**
 * Check if latest_products section separator is enabled.
 *
 * @since  Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_latest_products_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'workart_pro_theme_options[latest_products_content_type]' )->value();
    return workart_pro_is_latest_products_section_enable( $control ) && !( 'product-category' == $content_type );
}

/**
 * Check if section is enabled in third design.
 *
 * @since Workart Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function workart_pro_is_third_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'workart_pro_theme_options[home_layout]' )->value();
	return (  $home_layout == 'third-design' ||  $home_layout == 'default-design' );
}


function workart_pro_is_default_layout( $control ) {
	$design = $control->manager->get_setting( 'workart_pro_theme_options[home_layout]' )->value();
	return ( 'default-design' == $design );
}

function workart_pro_is_pro_layout( $control ) {
	$design = $control->manager->get_setting( 'workart_pro_theme_options[home_layout]' )->value();
	return ( 'pro-design' == $design );
}


function workart_pro_is_second_layout( $control ) {
	$design = $control->manager->get_setting( 'workart_pro_theme_options[home_layout]' )->value();
	return ( 'second-design' == $design );
}

function workart_pro_is_third_layout( $control ) {
	$design = $control->manager->get_setting( 'workart_pro_theme_options[home_layout]' )->value();
	return ( 'third-design' == $design );
}

function workart_pro_is_fourth_layout( $control ) {
	$design = $control->manager->get_setting( 'workart_pro_theme_options[home_layout]' )->value();
	return ( 'fourth-design' == $design );
}
