<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage  Workart Pro
 * @since  Workart Pro 1.0.0
 * @return array An array of default values
 */

function workart_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$workart_pro_default_options = array(
		// Color Options
		'header_title_color'			    => '#000',
		'header_tagline_color'			    => '#000',
		'header_txt_logo_extra'			    => 'show-all',
		'colorscheme_hue'				    => '#d87b4d',
		'colorscheme'					    => 'default',
		'theme_version'						=> 'lite-version',
		'home_layout'						=> 'default-design',

		// typography Options
		'theme_typography' 				    => 'default',
		'body_theme_typography' 		    => 'default',
		
		// loader
		'loader_enable'         		    => (bool) false,
		'loader_icon'         			    => 'default',

		// breadcrumb
		'breadcrumb_enable'				    => (bool) true,
		'breadcrumb_separator'			    => '/',
				
		// homepage options
		'enable_frontpage_content' 			=> false,

		// layout 
		'site_layout'         			    => 'wide',
		'sidebar_position'         		    => 'right-sidebar',
		'post_sidebar_position' 		    => 'right-sidebar',
		'page_sidebar_position' 		    => 'right-sidebar',
		'menu_sticky'					    => (bool) false,
		'search_icon_in_primary_menu_enable'=> (bool) true,
		'enable_cart_button'                => (bool) true,
		'enable_wishlist_button'            => (bool) false,

		// excerpt options
		'long_excerpt_length'               => 25,

		// pagination options
		'pagination_enable'         	    => (bool) true,
		'pagination_type'         		    => 'default',

		// footer options
		'copyright_text'           		    => sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s. ', '1: Year, 2: Site Title with home URL', 'workart-pro' ), '[the-year]', '[site-link]' ) . esc_html__( 'All Rights Reserved | ', 'workart-pro' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'workart-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	    => (bool) true,

		// reset options
		'reset_options'      			    => (bool) false,
		
		// homepage sections sortable
		'pro_sortable' 						=> 'featured_slider,hero_slider,about_us,recent_posts,our_services,featured_artist,gallery,featured_posts,popular_products,products_collection,recent_products,latest_products,featured_products,trending_products,testimonial,call_to_action,latest_posts,subscribe,our_partners',

		'default_sortable' 			    	=> 'hero_slider,about_us,our_services,featured_artist,gallery,testimonial,call_to_action,latest_posts,subscribe',

		'second_sortable' 					=> 'featured_slider,about_us,our_services,featured_artist,gallery,recent_products,testimonial,call_to_action,latest_posts,subscribe,our_partners',

		'third_sortable' 					=> 'featured_slider,about_us,recent_posts,gallery,featured_posts,recent_products,call_to_action,latest_posts,subscribe',

		'fourth_sortable'  					=> 'featured_slider,popular_products,products_collection,recent_products,latest_products,featured_products,trending_products,latest_posts,subscribe,our_services,our_partners',
		

		// blog/archive options
		'your_latest_posts_title' 		    => esc_html__( 'Blogs', 'workart-pro' ),
		'blog_column'						=> 'col-2',


		// single post theme options
		'single_post_hide_date' 		    => (bool) false,
		'single_post_hide_author'		    => (bool) false,
		'single_post_hide_category'		    => (bool) false,
		'single_post_hide_tags'			    => (bool) false,
		'hide_author'			   			=> (bool) true,
		'hide_date'			   				=> (bool) false,
		'hide_category'			   			=> (bool) false,

		/* Front Page */

		// top bar
		'topbar_section_enable'			=> (bool) true,
		'topbar_contact_number'			=> esc_html__('123456789','workart-pro'),
		'topbar_contact_email'			=> esc_html__('support@gmail.com','workart-pro'),
		'topbar_contact_location'		=> esc_html__('Kupandole, Lalitpur','workart-pro'),
		'social_menu_enable'			=> (bool) true,
		
		// Slider
		'featured_slider_section_enable'		=> (bool) true,
		'featured_slider_content_type'			=> 'post',
		'featured_slider_count'					=> 3,
		'featured_slider_autoplay_enable'		=> (bool) false,
		'featured_slider_excerpt_length'		=> 25,
		'featured_slider_btn_txt'               => esc_html__('Learn More','workart-pro'),
		'featured_slider_btn_alt_txt'           => esc_html__('Get Started','workart-pro'),

		// hero slider
		'hero_slider_section_enable'			=> (bool) true,
		'hero_slider_content_type'				=> 'post',
		'hero_slider_count'						=> 5,
		'hero_slider_excerpt_length'			=> 25,
		'hero_slider_section_sub_title'	        => esc_html__('Contemporary Abstract Artist','workart-pro'),
		'hero_slider_section_title'             => esc_html__('Sean Kernan','workart-pro'),
		'hero_slider_btn_txt'                   => esc_html__('Purchase Now','workart-pro'),
		'hero_slider_price_title'               => esc_html__('Estimate','workart-pro'),

		// featured post
		'featured_posts_section_enable'			=> (bool) true,
		'featured_posts_content_type'			=> 'page',
		'featured_posts_count'					=> 3,
		'featured_posts_sub_title'              => esc_html__('Featured Posts','workart-pro'),
		'featured_posts_title'    			    => esc_html__('Destination Guides','workart-pro'),
		
		//popular_posts 
		'popular_posts_section_enable'		   => (bool) true,
		'popular_posts_content_type'		   => 'post',
		'popular_posts_sub_title'              => esc_html__('Fashion','workart-pro'),
		'popular_posts_title'    			   => esc_html__('Popular Post','workart-pro'),
		'popular_posts_count'				   => 3,
		'popular_posts_column'				   => 'col-3',
		'popular_posts_read_more_btn_label'    => esc_html__('Read Full Post','workart-pro'),
		
		//latest_post 
		'latest_posts_section_enable'		   => (bool) true,
		'latest_posts_content_type'			   => 'post',
		'latest_posts_sub_title'               => esc_html__('Our Blogs','workart-pro'),
		'latest_posts_title'    			   => esc_html__('Stories Around Arts','workart-pro'),
		'latest_posts_count'				   => 3,
		'latest_posts_column'				   => 'col-3',
		'latest_posts_read_more_btn_label'     => esc_html__('Read More','workart-pro'),
		
		//recent_posts 
		'recent_posts_section_enable'		   => (bool) true,
		'recent_posts_content_type'			   => 'post',
		'recent_posts_count'				   => 3,
		'recent_posts_excerpt_length'		   => 30,
		'recent_posts_column'				   => 'col-3',
		'recent_posts_read_more_btn_label'     => esc_html__('Read More','workart-pro'),
		'recent_posts_title'				   => esc_html__( 'From Our Blogs', 'workart-pro' ),
		'recent_posts_sub_title'          	   => esc_html__('Recent Articles','workart-pro'),

		//popular product
		'popular_products_section_enable'	    => true,
		'popular_products_content_type'		    => 'product',
		'popular_products_count'				=> 3,
		'popular_products_title'				=> esc_html__( 'Popular Products', 'workart-pro' ),
		'popular_products_sub_title'			=> esc_html__( 'Browse Products', 'workart-pro' ),
		'popular_products_btn_title'			=> esc_html__( 'Add To Cart', 'workart-pro' ),

		// recent products
		'recent_products_section_enable'		=> (bool) true,
		'recent_products_count'					=> 3,
		'recent_products_title'					=> esc_html__('Our Products','workart-pro'),
		'recent_products_sub_title'				=> esc_html__('Discover','workart-pro'),
		'recent_products_add_to_cart_btn_label'	=> esc_html__('Add To Cart','workart-pro'),
		'recent_products_content_type'			=> 'product',
				
		// featured_artist
		'featured_artist_section_enable'		=> (bool) true,
		'featured_artist_content_type'			=> 'post',
		'featured_artist_sub_title'				=> esc_html__( 'Featured Artist', 'workart-pro' ),
		'featured_artist_count'					=> 3,
						
		//latest Products
		'latest_products_section_enable'		=> true,
		'latest_products_content_type'		    => 'product',
		'latest_products_count'				    => 2,

		//our service
		'our_services_section_enable'		    => (bool) true,
		'our_services_content_type'			    =>'post',
		'our_services_section_sub_title'		=> esc_html__( 'Why choose us?', 'workart-pro' ),
		'our_services_posts_count'			    => 3,
		'our_services_column'			 		=> 'col-3',
		'our_services_excerpt_length'			=> 20,
		'our_services_section_title'			=> esc_html__( 'WorkArt Services', 'workart-pro' ),

		//testimonial
        'testimonial_section_enable'            => (bool) true,
        'testimonial_autoplay_enable'           => (bool) true,
		'testimonial_sub_title'	        	    	=> esc_html__('Testimonials','workart-pro'),
		'testimonial_content_type'              => 'post',
		'testimonial_excerpt_length'            => 10,
		'testimonial_posts_count'               => 3,
		
		//trending Products
		'trending_products_section_enable'	=> true,
		'trending_products_content_type'	=> 'product',
		'trending_products_count'			=> 3,
		'trending_products_title'			=> esc_html__( 'Latest Collection', 'workart-pro' ),
	
		// gallery
		'gallery_section_enable'		=> (bool) true,
		'gallery_sub_title'         	=> esc_html__('Projects','workart-pro'),
		'gallery_content_type'			=> 'recent',
		'gallery_count'					=> 6,
		'gallery_title'					=> esc_html__( 'Our Art Gallery', 'workart-pro' ),
		'gallery_btn_txt'				=> esc_html__( 'Show All', 'workart-pro' ),

		//about us
		'about_us_section_enable'			=> (bool) true,
		'about_us_content_type'			    =>'custom',
		'about_us_custom_title'				=> esc_html__('The WorkArt is a marketplace for artists','workart-pro'),
		'about_us_custom_content'			=> __('The arts, however, are a polar opposite to pragmatism. Cameras have long exceeded our ability to realistically and efficiently render images, but still our love of painting remains to this day. By now we know that the value of a great painting isn’t in its accuracy at rendering a view.','workart-pro'),
		'about_us_custom_sub_title'			=> esc_html__('About WorkArt','workart-pro'),
		'about_us_excerpt_length'			=> 40,
		'about_us_btn_txt'                  => esc_html__('Make Appointment','workart-pro'),

		//subscribe
		'subscribe_section_enable' 			=> true,
		'subscribe_section_title'			=>	esc_html__('Get More News.', 'workart-pro'),
		'subscribe_section_subtitle'		=>	esc_html__('Subscribe Now!', 'workart-pro'),
		'subscribe_section_description'		=>	esc_html__('Enter your email address to get more information about our art gallery and artists. We are more than original.', 'workart-pro'),
		'subscribe_section_btn_txt'			=>	esc_html__('Subscribe Now', 'workart-pro'),
						
		
		//call_to_action
		'call_to_action_section_enable' 	=> true,
		'call_to_action_content_type'		=> 'post',
		'call_to_action_read_more'			=>	esc_html__('Read More', 'workart-pro'),
		'call_to_action_sub_title'			=>	esc_html__('Call To Action', 'workart-pro'),
		'call_to_action_excerpt_length'		=>	25,
		'call_to_action_custom_title'		=> esc_html__('Power of Colors.','workart-pro'),
		'call_to_action_custom_content'		=> __('The arts, however, are a polar opposite to pragmatism. Cameras have long exceeded our ability to realistically and efficiently render images, but still our love of painting remains to this day. By now we know that the value of a great painting isn’t in its accuracy at rendering a view.','workart-pro'),

		//our_partners
		'our_partners_section_enable'		=> (bool) true,
		'our_partners_content_type'			=> 'custom',
		'our_partners_count'				=> 4,

		//Product Collection
		'products_collection_section_enable'	=> true,
		'products_collection_content_type'	=> 'product',
		'products_collection_count'			=> 4,
		'products_collection_title'			=> esc_html__( 'Products Collection', 'workart-pro' ),
		'products_collection_subtitle'		=> esc_html__( 'Browse Products', 'workart-pro' ),
		'products_collection_btn_title'		=> esc_html__( 'Start Shopping', 'workart-pro' ),


		// recent products
		'featured_products_section_enable'	=> (bool) true,
		'featured_products_count'			=> 2,
		'featured_products_btn_title'		=> esc_html__('Buy Now','workart-pro'),
		'featured_products_content_type'	=> 'product',

	);

	$output = apply_filters( 'workart_pro_default_theme_options', $workart_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}