<?php
/**
 * About Section options
 *
 * @package Theme Palace
 * @subpackage Workart Pro
 * @since Workart Pro 1.0.0
 */

// Add About section
$wp_customize->add_section( 'workart_pro_about_us_section',
	array(
		'title'             => esc_html__( 'About us','workart-pro' ),
		'description'       => esc_html__( 'About us  Section options.', 'workart-pro' ),
        'panel'             => 'workart_pro_front_page_panel',
		'active_callback'	=> function( $control ) {
            return (
                workart_pro_is_pro_layout( $control )
                ||
                workart_pro_is_default_layout( $control )
                ||
                workart_pro_is_second_layout( $control )
                ||
                workart_pro_is_third_layout( $control )
            );
        },
	)
);

// About content enable control and setting
$wp_customize->add_setting( 'workart_pro_theme_options[about_us_section_enable]',
	array(
		'default'			=> 	$options['about_us_section_enable'],
		'sanitize_callback' => 'workart_pro_sanitize_switch_control',
	)
);

$wp_customize->add_control( new Workart_Pro_Switch_Control( $wp_customize,
	'workart_pro_theme_options[about_us_section_enable]',
		array(
			'label'             => esc_html__( 'About Section Enable', 'workart-pro' ),
			'section'           => 'workart_pro_about_us_section',
			'on_off_label' 		=> workart_pro_switch_options(),
		)
	)
);

// About title setting
$wp_customize->add_setting('workart_pro_theme_options[about_us_custom_sub_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['about_us_custom_sub_title']
    )
);

$wp_customize->add_control('workart_pro_theme_options[about_us_custom_sub_title]',
    array(
        'section'			=> 'workart_pro_about_us_section',
        'label'				=> esc_html__( 'Section Sub Title:', 'workart-pro' ),
        'type'          	=>'text',
        'active_callback' 	=> 'workart_pro_if_about_us_section_content_custom_enable'
    )
);

$wp_customize->selective_refresh->add_partial('workart_pro_theme_options[about_us_custom_sub_title]',
    array(
        'selector'            => '#workart_pro_about_us_section div.section-header p.section-subtitle',
        'render_callback'     => 'workart_pro_about_us_custom_sub_title_partial',
    )
);

// About Excerpt length setting and control.
$wp_customize->add_setting( 'workart_pro_theme_options[about_us_excerpt_length]',
	array(
		'sanitize_callback' => 'workart_pro_sanitize_number_range',
		'default'			=> $options['about_us_excerpt_length'],
	)
);

$wp_customize->add_control( 'workart_pro_theme_options[about_us_excerpt_length]',
	array(
		'label'       		=> esc_html__( 'Excerpt Length', 'workart-pro' ),
		'description' 		=> esc_html__( 'Total words to be displayed in About section', 'workart-pro' ),
		'section'     		=> 'workart_pro_about_us_section',
		'type'        		=> 'number',
		'active_callback' 	=> 'workart_pro_is_about_us_section_enable',
	)
);

// About content type control and setting
$wp_customize->add_setting( 'workart_pro_theme_options[about_us_content_type]',
	array(
		'default'          	=> $options['about_us_content_type'],
		'sanitize_callback' => 'workart_pro_sanitize_select',
	)
);

$wp_customize->add_control( 'workart_pro_theme_options[about_us_content_type]',
	array(
		'label'             => esc_html__( 'Content Type', 'workart-pro' ),
		'section'           => 'workart_pro_about_us_section',
		'type'				=> 'select',
		'active_callback' 	=> 'workart_pro_is_about_us_section_enable',
		'choices'			=> array( 
			'page' 		=> esc_html__( 'Page', 'workart-pro' ),
			'post' 		=> esc_html__( 'Post', 'workart-pro' ),
			'category' 	=> esc_html__( 'Category', 'workart-pro' ),
			'custom' 	=> esc_html__( 'Custom', 'workart-pro' ),
		),
	)
);

	// about pages drop down chooser control and setting
	$wp_customize->add_setting( 'workart_pro_theme_options[about_us_content_page]',
		array(
			'sanitize_callback' => 'workart_pro_sanitize_page',
		)
	);

	$wp_customize->add_control( new Workart_Pro_Dropdown_Chooser( $wp_customize,
		'workart_pro_theme_options[about_us_content_page]',
			array(
				'label'             => esc_html__( 'Select Page', 'workart-pro' ),
				'section'           => 'workart_pro_about_us_section',
				'choices'			=> workart_pro_page_choices(),
				'active_callback'	=> 'workart_pro_is_about_us_section_content_page_enable',
			)
		)
	);

	// about posts drop down chooser control and setting
	$wp_customize->add_setting( 'workart_pro_theme_options[about_us_content_post]',
		array(
			'sanitize_callback' => 'workart_pro_sanitize_page',
		)
	);

	$wp_customize->add_control( new Workart_Pro_Dropdown_Chooser( $wp_customize,
		'workart_pro_theme_options[about_us_content_post]',
			array(
				'label'             => esc_html__( 'Select Post', 'workart-pro' ),
				'section'           => 'workart_pro_about_us_section',
				'choices'			=> workart_pro_post_choices(),
				'active_callback'	=> 'workart_pro_is_about_us_section_content_post_enable',
			)
		)
	);


// about posts drop down chooser control and setting
$wp_customize->add_setting( 'workart_pro_theme_options[about_us_category]',
	array(
		'sanitize_callback' => 'workart_pro_sanitize_single_category',
	)
);

$wp_customize->add_control( new Workart_Pro_Dropdown_Taxonomies_Control( $wp_customize,
	'workart_pro_theme_options[about_us_category]',
		array(
			'label'             => esc_html__( 'Select Categories', 'workart-pro' ),
			'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'workart-pro' ),
			'type'           	=> 'dropdown-taxonomies',
			'section'           => 'workart_pro_about_us_section',
			'active_callback'	=> 'workart_pro_is_about_us_section_content_category_enable',
		)
	)
); 

// About title setting
$wp_customize->add_setting('workart_pro_theme_options[about_us_custom_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['about_us_custom_title']
    )
);

$wp_customize->add_control('workart_pro_theme_options[about_us_custom_title]',
    array(
        'section'			=> 'workart_pro_about_us_section',
        'label'				=> esc_html__( 'Custom Title:', 'workart-pro' ),
        'type'          	=>'text',
        'active_callback' 	=> 'workart_pro_if_about_us_section_content_custom_enable'
    )
);

$wp_customize->selective_refresh->add_partial('workart_pro_theme_options[about_us_custom_title]',
    array(
        'selector'            => '#workart_pro_about_us_section div.section-header h2.section-title',
        'render_callback'     => 'workart_pro_about_us_custom_title_partial',
    )
);

// About content setting
$wp_customize->add_setting('workart_pro_theme_options[about_us_custom_content]',
    array(
        'sanitize_callback' => 'workart_pro_sanitize_html',
        'transport'			=> 'postMessage',
        'default'           => $options['about_us_custom_content']

    )
);

$wp_customize->add_control('workart_pro_theme_options[about_us_custom_content]',
    array(
        'section'			=> 'workart_pro_about_us_section',
        'label'				=> esc_html__( 'Custom Content:', 'workart-pro' ),
        'type'          	=>'textarea',
        'active_callback'	=> 'workart_pro_if_about_us_section_content_custom_enable',
		'input_attrs'       => array(
			'rows'=> 4,
			'cols'=> 50
        ),
    )
);

$wp_customize->selective_refresh->add_partial('workart_pro_theme_options[about_us_custom_content]',
	array(
		'selector'            => '#workart_pro_about_us_section div.entry-content p',
		'render_callback'     => 'workart_pro_about_us_custom_content_partial',
	)
);

$wp_customize->add_setting( 'workart_pro_theme_options[about_us_custom_image]',
	array(
		'sanitize_callback' => 'workart_pro_sanitize_image',
	)
);

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize,
	'workart_pro_theme_options[about_us_custom_image]',
		array(
			'label'       		=> esc_html__( 'Custom Image', 'workart-pro' ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'workart-pro' ), 550, 521 ),
			'section'     		=> 'workart_pro_about_us_section',
			'active_callback'	=> 'workart_pro_if_about_us_section_content_custom_enable',
		)
	)
);

//about_us_btn_txt
$wp_customize->add_setting('workart_pro_theme_options[about_us_btn_txt]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['about_us_btn_txt'],
    )
);

$wp_customize->add_control('workart_pro_theme_options[about_us_btn_txt]',
    array(
        'section'			=> 'workart_pro_about_us_section',
        'label'				=> esc_html__( 'Button Text:', 'workart-pro' ),
        'type'          	=>'text',
        'active_callback' 	=> 'workart_pro_is_about_us_section_enable'
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'workart_pro_theme_options[about_us_btn_txt]',
		array(
			'selector'            => '#workart_pro_about_us_section div.read-more a:nth-child(1)',
			'settings'            => 'workart_pro_theme_options[about_us_btn_txt]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'workart_pro_about_us_btn_txt_partial',
		)
	);
}

$wp_customize->add_setting( 'workart_pro_theme_options[about_us_btn_url]',
	array(
		'sanitize_callback' => 'esc_url_raw',
	)
);

$wp_customize->add_control( 'workart_pro_theme_options[about_us_btn_url]',
	array(
		'label'           	=>  esc_html__( 'Custom Button Link ', 'workart-pro' ),
		'section'        	=> 'workart_pro_about_us_section',
		'active_callback' 	=> 'workart_pro_if_about_us_section_content_custom_enable',
		'type'				=> 'url',
	)
);

for($i=2; $i<=3; $i++){
	$wp_customize->add_setting( 'workart_pro_theme_options[about_us_custom_image' . $i . ']',
		array(
			'sanitize_callback' => 'workart_pro_sanitize_image',
		)
	);
	
	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize,
		'workart_pro_theme_options[about_us_custom_image' . $i . ']',
			array(
				'label'       		=> esc_html__( 'Extra Image', 'workart-pro' ),
				'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'workart-pro' ), 550, 521 ),
				'section'     		=> 'workart_pro_about_us_section',
				'active_callback'	=> 'workart_pro_is_about_us_section_enable',
			)
		)
	);
}