<?php
/**
 * Call To Action Section options
 *
 * @package Theme Palace
 * @subpackage  Workart Pro
 * @since  Workart Pro 1.0.0
 */

// Add Call To Action section
$wp_customize->add_section( 'workart_pro_call_to_action_section',
    array(
        'title'             => esc_html__( 'Call To Action','workart-pro' ),
        'description'       => esc_html__( 'Call To Action Section options.', 'workart-pro' ),
        'panel'             => 'workart_pro_front_page_panel',
        'active_callback'	=> function( $control ) {
            return (
                workart_pro_is_pro_layout( $control )
                ||
                workart_pro_is_default_layout( $control )
                ||
                workart_pro_is_second_layout( $control )
                ||
                workart_pro_is_third_layout( $control )
            );
        },
    )
);

// Call To Action content enable control and setting
$wp_customize->add_setting( 'workart_pro_theme_options[call_to_action_section_enable]',
    array(
        'default'			=> 	$options['call_to_action_section_enable'],
        'sanitize_callback' => 'workart_pro_sanitize_switch_control',
    )
);

$wp_customize->add_control( new  Workart_Pro_Switch_Control( $wp_customize,
    'workart_pro_theme_options[call_to_action_section_enable]',
        array(
            'label'             => esc_html__( 'Call To Action Section Enable', 'workart-pro' ),
            'section'           => 'workart_pro_call_to_action_section',
            'on_off_label' 		=> workart_pro_switch_options(),
        )
    )
);

// call_to_actionsection sub title control and setting
$wp_customize->add_setting('workart_pro_theme_options[call_to_action_sub_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport' => 'postMessage',
        'default'  => $options['call_to_action_sub_title'],
    )
);

$wp_customize->add_control('workart_pro_theme_options[call_to_action_sub_title]',
    array(
        'label' => esc_html__('Section Sub Title', 'workart-pro'),
        'section' => 'workart_pro_call_to_action_section',
        'type' => 'text',
        'active_callback' => 'workart_pro_is_call_to_action_section_enable',
    )
);

$wp_customize->selective_refresh->add_partial('workart_pro_theme_options[call_to_action_sub_title]',
    array(
        'selector' => '#workart_pro_call_to_action_section .section-subtitle',
        'render_callback' => 'workart_pro_call_to_action_sub_title_partial',
    )
);
// Call To Action content type control and setting
$wp_customize->add_setting( 'workart_pro_theme_options[call_to_action_content_type]',
    array(
        'default'          	=> $options['call_to_action_content_type'],
        'sanitize_callback' => 'workart_pro_sanitize_select',
    ) 
);

$wp_customize->add_control( 'workart_pro_theme_options[call_to_action_content_type]',
    array(
        'label'             => esc_html__( 'Content Type', 'workart-pro' ),
        'section'           => 'workart_pro_call_to_action_section',
        'type'				=> 'select',
        'active_callback' 	=> 'workart_pro_is_call_to_action_section_enable',
        'choices'			=> array(
            'page' 		=> esc_html__( 'Page', 'workart-pro' ),
			'post' 		=> esc_html__( 'Post', 'workart-pro' ),
			'custom'	=> esc_html__( 'Custom', 'workart-pro' ),
        ),
    )
);

$wp_customize->add_setting( 'workart_pro_theme_options[call_to_action_content_page]',
    array(
        'sanitize_callback' => 'workart_pro_sanitize_page',
    )
);

$wp_customize->add_control( new  Workart_Pro_Dropdown_Chooser( $wp_customize,
    'workart_pro_theme_options[call_to_action_content_page]',
        array(
            'label'             => esc_html__( 'Select Page', 'workart-pro' ),
            'section'           => 'workart_pro_call_to_action_section',
            'choices'			=> workart_pro_page_choices(),
            'active_callback'	=> 'workart_pro_is_call_to_action_section_content_page_enable',
        )
    )
);

// Call To Action posts drop down chooser control and setting
$wp_customize->add_setting( 'workart_pro_theme_options[call_to_action_content_post]',
    array(
        'sanitize_callback' => 'workart_pro_sanitize_page',
    )
);

$wp_customize->add_control( new  Workart_Pro_Dropdown_Chooser( $wp_customize,
    'workart_pro_theme_options[call_to_action_content_post]',
        array(
            'label'             => esc_html__( 'Select posts', 'workart-pro' ),
            'section'           => 'workart_pro_call_to_action_section',
            'choices'			=> workart_pro_post_choices(),
            'active_callback'	=> 'workart_pro_is_call_to_action_section_content_post_enable',
        )
    ) 
);

// About title setting
$wp_customize->add_setting('workart_pro_theme_options[call_to_action_custom_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['call_to_action_custom_title']
    )
);

$wp_customize->add_control('workart_pro_theme_options[call_to_action_custom_title]',
    array(
        'section'			=> 'workart_pro_call_to_action_section',
        'label'				=> esc_html__( 'Custom Title:', 'workart-pro' ),
        'type'          	=>'text',
        'active_callback' 	=> 'workart_pro_if_call_to_action_section_content_custom_enable'
    )
);

$wp_customize->selective_refresh->add_partial('workart_pro_theme_options[call_to_action_custom_title]',
    array(
        'selector'            => '#workart_pro_call_to_action_section div.section-header h2.section-title',
        'render_callback'     => 'workart_pro_call_to_action_custom_title_partial',
    )
);

// About content setting
$wp_customize->add_setting('workart_pro_theme_options[call_to_action_custom_content]',
    array(
        'sanitize_callback' => 'workart_pro_sanitize_html',
        'transport'			=> 'postMessage',
        'default'           => $options['call_to_action_custom_content']

    )
);

$wp_customize->add_control('workart_pro_theme_options[call_to_action_custom_content]',
    array(
        'section'			=> 'workart_pro_call_to_action_section',
        'label'				=> esc_html__( 'Custom Content:', 'workart-pro' ),
        'type'          	=>'textarea',
        'active_callback'	=> 'workart_pro_if_call_to_action_section_content_custom_enable',
		'input_attrs'       => array(
			'rows'=> 4,
			'cols'=> 50
        ),
    )
);

$wp_customize->selective_refresh->add_partial('workart_pro_theme_options[call_to_action_custom_content]',
	array(
		'selector'            => '#workart_pro_call_to_action_section div.entry-content p',
		'render_callback'     => 'workart_pro_call_to_action_custom_content_partial',
	)
);

$wp_customize->add_setting( 'workart_pro_theme_options[call_to_action_custom_image]',
	array(
		'sanitize_callback' => 'workart_pro_sanitize_image',
	)
);

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize,
	'workart_pro_theme_options[call_to_action_custom_image]',
		array(
			'label'       		=> esc_html__( 'Custom Image', 'workart-pro' ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'workart-pro' ), 550, 521 ),
			'section'     		=> 'workart_pro_call_to_action_section',
			'active_callback'	=> 'workart_pro_if_call_to_action_section_content_custom_enable',
		)
	)
);

// Call To Action read more setting and control
$wp_customize->add_setting( 'workart_pro_theme_options[call_to_action_read_more]',
    array(
        'default'			=> $options['call_to_action_read_more'],
        'sanitize_callback' => 'sanitize_text_field',
        'transport'         =>'postMessage',
    )
);

$wp_customize->add_control( 'workart_pro_theme_options[call_to_action_read_more]',
    array(
        'label'           	=> esc_html__( 'Read More Text', 'workart-pro' ),
        'section'        	=> 'workart_pro_call_to_action_section',
        'active_callback' 	=> 'workart_pro_is_call_to_action_section_enable',
        'type'				=> 'text',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'workart_pro_theme_options[call_to_action_read_more]',
        array(
            'selector'            => '#call_to_action-section div.read-more a.btn',
            'settings'            => 'workart_pro_theme_options[call_to_action_read_more]',
            'container_inclusive' => false,
            'fallback_refresh'    => true,
            'render_callback'     => 'workart_pro_call_to_action_read_more_partial',
        )
    );
}

$wp_customize->add_setting( 'workart_pro_theme_options[call_to_action_btn_url]',
	array(
		'sanitize_callback' => 'esc_url_raw',
	)
);

$wp_customize->add_control( 'workart_pro_theme_options[call_to_action_btn_url]',
	array(
		'label'           	=>  esc_html__( 'Custom Button Link ', 'workart-pro' ),
		'section'        	=> 'workart_pro_call_to_action_section',
		'active_callback' 	=> 'workart_pro_if_call_to_action_section_content_custom_enable',
		'type'				=> 'url',
	)
);

// Call To Action Excerpt length setting and control.
$wp_customize->add_setting( 'workart_pro_theme_options[call_to_action_excerpt_length]',
	array(
		'sanitize_callback' => 'workart_pro_sanitize_number_range',
		'default'			=> $options['call_to_action_excerpt_length'],
	)
);

$wp_customize->add_control( 'workart_pro_theme_options[call_to_action_excerpt_length]',
	array(
		'label'       		=> esc_html__( 'Excerpt Length', 'workart-pro' ),
		'description' 		=> esc_html__( 'Total words to be displayed in Call To Action section', 'workart-pro' ),
		'section'     		=> 'workart_pro_call_to_action_section',
		'type'        		=> 'number',
        'active_callback'	=> function( $control ) {
            return (
                workart_pro_is_call_to_action_section_content_post_enable( $control )
                ||
                workart_pro_is_call_to_action_section_content_page_enable( $control )
            );
        },
	)
);
