<?php
/**
 * Featured Artist Section options
 *
 * @package Theme Palace
 * @subpackage  Workart Pro
 * @since  Workart Pro 1.0.0
 */

// Add Featured Artist section
$wp_customize->add_section( 'workart_pro_featured_artist_section',
	array(
		'title'             => esc_html__( 'Featured Artist','workart-pro' ),
		'description'       => esc_html__( 'Featured Artist Section options.', 'workart-pro' ),
		'panel'             => 'workart_pro_front_page_panel',
		'active_callback'	=> function( $control ) {
            return (
                workart_pro_is_pro_layout( $control )
                ||
                workart_pro_is_default_layout( $control )
                ||
                workart_pro_is_second_layout( $control )
            );
        },
	) 
);

// Featured Artist content enable control and setting
$wp_customize->add_setting( 'workart_pro_theme_options[featured_artist_section_enable]', 
	array(
		'default'			=> 	$options['featured_artist_section_enable'],
		'sanitize_callback' => 'workart_pro_sanitize_switch_control',
	) 
);

$wp_customize->add_control( new  Workart_Pro_Switch_Control( $wp_customize,
	'workart_pro_theme_options[featured_artist_section_enable]',
		array(
			'label'             => esc_html__( 'Featured Artist Section Enable', 'workart-pro' ),
			'section'           => 'workart_pro_featured_artist_section',
			'on_off_label' 		=> workart_pro_switch_options(),
		)
	)
);

// Featured artist sub title setting
$wp_customize->add_setting('workart_pro_theme_options[featured_artist_sub_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['featured_artist_sub_title']
    )
);

$wp_customize->add_control('workart_pro_theme_options[featured_artist_sub_title]',
    array(
        'section'			=> 'workart_pro_featured_artist_section', 
        'label'				=> esc_html__( 'Section Sub Title:', 'workart-pro' ),
        'type'          	=>'text',
        'active_callback' 	=> 'workart_pro_is_featured_artist_section_enable'
    )
);

$wp_customize->selective_refresh->add_partial('workart_pro_theme_options[featured_artist_sub_title]',
    array(
        'selector'            => '#workart_pro_featured_artist_section div.section-header p.section-subtitle',
        'render_callback'     => 'workart_pro_featured_artist_sub_title_partial',
    )
);
// Featured Artist number control and setting
$wp_customize->add_setting( 'workart_pro_theme_options[featured_artist_count]',
	array(
		'default'          	=> $options['featured_artist_count'],
		'sanitize_callback' => 'workart_pro_sanitize_number_range',
		'validate_callback' => 'workart_pro_validate_featured_artist_count',
	)
);

$wp_customize->add_control( 'workart_pro_theme_options[featured_artist_count]',
	array(
		'label'             => esc_html__( 'Number of Post', 'workart-pro' ),
		'description'       => esc_html__( 'Note: Min 1 & Max 9. Please input the valid number and save. Then refresh the page to see the change.', 'workart-pro' ),
		'section'           => 'workart_pro_featured_artist_section',
		'active_callback'   => 'workart_pro_is_featured_artist_section_enable',
		'type'				=> 'number',
		'input_attrs'		=> array(
			'min'	=> 1,
			'max'	=> 9,
			'style' => 'width: 100px;'
		),
	)
);

// Featured Artist content type control and setting
$wp_customize->add_setting( 'workart_pro_theme_options[featured_artist_content_type]',
	array(
		'default'          	=> $options['featured_artist_content_type'],
		'sanitize_callback' => 'workart_pro_sanitize_select',
	)
);

$wp_customize->add_control( 'workart_pro_theme_options[featured_artist_content_type]',
	array(
		'label'             => esc_html__( 'Content Type', 'workart-pro' ),
		'section'           => 'workart_pro_featured_artist_section',
		'type'				=> 'select',
		'active_callback' 	=> 'workart_pro_is_featured_artist_section_enable',
		'choices'			=> array( 
			'page' 		=> esc_html__( 'Page', 'workart-pro' ),
			'post' 		=> esc_html__( 'Post', 'workart-pro' ),
			'category' 	=> esc_html__( 'Category', 'workart-pro' ),
		),
	)
);


for ( $i = 1; $i <= $options['featured_artist_count']; $i++ ) :

	// featured_artist pages drop down chooser control and setting
	$wp_customize->add_setting( 'workart_pro_theme_options[featured_artist_content_page_'. $i .']', 
		array(
			'sanitize_callback' => 'workart_pro_sanitize_page',
		)
	);

	$wp_customize->add_control( new  Workart_Pro_Dropdown_Chooser( $wp_customize,
		'workart_pro_theme_options[featured_artist_content_page_'. $i .']', 
			array(
				'label'             => sprintf(esc_html__( 'Select Page: %d', 'workart-pro'), $i ),
				'section'           => 'workart_pro_featured_artist_section',
				'choices'			=> workart_pro_page_choices(),
				'active_callback'	=> 'workart_pro_is_featured_artist_section_content_page_enable',
			)
		)
	);

	// featured_artist posts drop down chooser control and setting
	$wp_customize->add_setting( 'workart_pro_theme_options[featured_artist_content_post_'. $i .']', 
		array(
			'sanitize_callback' => 'workart_pro_sanitize_page',
		)
	);

	$wp_customize->add_control( new  Workart_Pro_Dropdown_Chooser( $wp_customize,
		'workart_pro_theme_options[featured_artist_content_post_'. $i .']',
			array(
				'label'             => sprintf(esc_html__( 'Select Post : %d', 'workart-pro'), $i ),
				'section'           => 'workart_pro_featured_artist_section',
				'choices'			=> workart_pro_post_choices(),
				'active_callback'	=> 'workart_pro_is_featured_artist_section_content_post_enable',
			)
		)
	);

	// Workart_Pro_Customize_Horizontal_Line
    $wp_customize->add_setting('workart_pro_theme_options[featured_artist_separator'. $i .']',
		array(
			'sanitize_callback'      => 'workart_pro_sanitize_html',
		)
	);

    $wp_customize->add_control(new Workart_Pro_Customize_Horizontal_Line($wp_customize,
		'workart_pro_theme_options[featured_artist_separator'. $i .']',
			array(
				'active_callback'       => 'workart_pro_is_featured_artist_section_separator_enable',
				'type'                  =>'hr',
				'section'               =>'workart_pro_featured_artist_section',
			)
		)
	);

endfor;

// featured_artist posts drop down chooser control and setting
$wp_customize->add_setting( 'workart_pro_theme_options[featured_artist_category]',
	array(
		'sanitize_callback' => 'workart_pro_sanitize_single_category',
	)
);

$wp_customize->add_control( new  Workart_Pro_Dropdown_Taxonomies_Control( $wp_customize,
	'workart_pro_theme_options[featured_artist_category]', 
		array(
			'label'             => esc_html__( 'Select Categories', 'workart-pro' ),
			'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'workart-pro' ),
			'type'           	=> 'dropdown-taxonomies',
			'section'           => 'workart_pro_featured_artist_section',
			'active_callback'	=> 'workart_pro_is_featured_artist_section_content_category_enable',
		)
	)
); 

