<?php
/**
 * Featured Products Section options
 *
 * @package Theme Palace
 * @subpackage Workart Pro
 * @since Workart Pro 1.0.0
 */
if ( !class_exists('WooCommerce') ) {
    return;
}

// Add featured_products section
$wp_customize->add_section( 'workart_pro_featured_products_section',
    array(
        'title'             => esc_html__( 'Featured Product','workart-pro' ),
        'description'       => esc_html__( 'Note: To activate this section you need to install WooCommerce Plugin.', 'workart-pro' ),
        'panel'             => 'workart_pro_front_page_panel',
        'active_callback'	=> function( $control ) {
            return (
                workart_pro_is_pro_layout( $control )
                ||
                workart_pro_is_fourth_layout( $control )
            );
        },
    )
);

// featured_products content enable control and setting
$wp_customize->add_setting( 'workart_pro_theme_options[featured_products_section_enable]',
    array(
        'default'           =>  $options['featured_products_section_enable'],
        'sanitize_callback' => 'workart_pro_sanitize_switch_control',
    )
);

$wp_customize->add_control( new Workart_Pro_Switch_Control( $wp_customize,
    'workart_pro_theme_options[featured_products_section_enable]',
        array(
            'label'             => esc_html__( 'Featured Product Section Enable', 'workart-pro' ),
            'section'           => 'workart_pro_featured_products_section',
            'on_off_label'      => workart_pro_switch_options(),
        )
    )
);

$wp_customize->add_setting( 'workart_pro_theme_options[featured_products_count]',
    array(
        'default'           => $options['featured_products_count'],
        'sanitize_callback' => 'workart_pro_sanitize_number_range',
        'validate_callback' => 'workart_pro_validate_featured_products_count',
    )
);

$wp_customize->add_control( 'workart_pro_theme_options[featured_products_count]',
    array(
        'label'             => esc_html__( 'Number of Product', 'workart-pro' ),
        'description'       => esc_html__( 'Note: Min 2 & Max 4. Please input the valid number and save. Then refresh the page to see the change.', 'workart-pro' ),
        'section'           => 'workart_pro_featured_products_section',
        'active_callback'   => 'workart_pro_is_featured_products_section_enable',
        'type'              => 'number',
        'input_attrs'       => array(
            'min'   => 2,
            'max'   => 4,
            'style' => 'width: 100px;'
        ),
    )
);

$wp_customize->add_setting( 'workart_pro_theme_options[featured_products_content_type]',
    array(
        'default'           => $options['featured_products_content_type'],
        'sanitize_callback' => 'workart_pro_sanitize_select',
    )
);

$wp_customize->add_control( 'workart_pro_theme_options[featured_products_content_type]',
    array(
        'label'             => esc_html__( 'Content Type', 'workart-pro' ),
        'section'           => 'workart_pro_featured_products_section',
        'type'              => 'select',
        'active_callback'   => 'workart_pro_is_featured_products_section_enable',
        'choices'           => workart_pro_featured_products_content_type()
    )
);

for( $i = 1 ; $i <= $options['featured_products_count'] ; $i++ ){

    $wp_customize->add_setting( 'workart_pro_theme_options[featured_products_content_product_' . $i . ']',
        array(
            'sanitize_callback' => 'workart_pro_sanitize_page',
        )
    );

    $wp_customize->add_control( new Workart_Pro_Dropdown_Chooser( $wp_customize,
        'workart_pro_theme_options[featured_products_content_product_' . $i . ']',
            array(
                'label'             => sprintf( esc_html__( 'Select Product %d', 'workart-pro' ), $i ),
                'section'           => 'workart_pro_featured_products_section',
                'choices'           => workart_pro_product_choices(),
                'active_callback'   => 'workart_pro_is_featured_products_section_content_product_enable',
            )
        )
    );

    // featured_products posts drop down chooser control and setting
    $wp_customize->add_setting( 'workart_pro_theme_options[featured_products_content_post_' . $i . ']',
        array(
            'sanitize_callback' => 'workart_pro_sanitize_page',
        )
    );

    $wp_customize->add_control( new Workart_Pro_Dropdown_Chooser( $wp_customize,
        'workart_pro_theme_options[featured_products_content_post_' . $i . ']',
            array(
                'label'             => sprintf( esc_html__( 'Select Post %d', 'workart-pro' ), $i ),
                'section'           => 'workart_pro_featured_products_section',
                'choices'           => workart_pro_post_choices(),
                'active_callback'   => 'workart_pro_is_featured_products_section_content_post_enable',
            )
        )
    );

	$wp_customize->add_setting( 'workart_pro_theme_options[featured_products_hr_'. $i .']',
        array(
            'sanitize_callback' => 'sanitize_text_field'
        )
    );

    $wp_customize->add_control( new Workart_Pro_Customize_Horizontal_Line( $wp_customize,
        'workart_pro_theme_options[featured_products_hr_'. $i .']',
            array(
                'section'         => 'workart_pro_featured_products_section',
                'active_callback' => 'workart_pro_is_featured_products_section_content_product_enable',
                'type'			  => 'hr'
            )
        )
    );

}

$wp_customize->add_setting(  'workart_pro_theme_options[featured_products_category]',
    array(
        'sanitize_callback' => 'absint',
    )
);

$wp_customize->add_control( new Workart_Pro_Dropdown_Taxonomies_Control( $wp_customize,
    'workart_pro_theme_options[featured_products_category]',
        array(
            'label'             => esc_html__( 'Select Product Categories', 'workart-pro' ),
            'description'       => esc_html__( 'Note: Press CTRL and select multiple category. Latest four posts will be shown from each selected category', 'workart-pro' ),
            'section'           => 'workart_pro_featured_products_section',
            'taxonomy'          => 'product_cat',
            'type'              => 'dropdown-taxonomies',
            'active_callback'   => 'workart_pro_is_featured_products_section_content_product_category_enable',
        )
    )
);

// featured product btn title setting and control
$wp_customize->add_setting( 'workart_pro_theme_options[featured_products_btn_title]',
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'           => $options['featured_products_btn_title'],
		'transport'			=> 'postMessage',
	)
);

$wp_customize->add_control( 'workart_pro_theme_options[featured_products_btn_title]',
	array(
		'label'           	=> esc_html__( 'Button Label ', 'workart-pro' ),
		'section'        	=> 'workart_pro_featured_products_section',
		'active_callback' 	=> 'workart_pro_is_featured_products_section_enable',
		'type'				=> 'text',
	)
);


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'workart_pro_theme_options[featured_products_btn_title]',
		array(
			'selector'            => '#workart_pro_featured_products_section div.read-more a',
			'settings'            => 'workart_pro_theme_options[featured_products_btn_title]',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'workart_pro_featured_products_btn_title_partial',
		)
	);
}
