<?php
/**
 * Featured Slider Section options
 *
 * @package Theme Palace
 * @subpackage  Workart Pro
 * @since  Workart Pro 1.0.0
 */

// Add Featured Slider section
$wp_customize->add_section( 'workart_pro_featured_slider_section',
	array(
		'title'             => esc_html__( 'Featured Slider','workart-pro' ),
		'description'       => esc_html__( 'Featured Slider Section options.', 'workart-pro' ),
		'panel'             => 'workart_pro_front_page_panel',
		'active_callback'	=> function( $control ) {
			return (
				workart_pro_is_pro_layout( $control )
				||
				workart_pro_is_second_layout( $control )
				||
				workart_pro_is_third_layout( $control )
				||
				workart_pro_is_fourth_layout( $control )
			);
		},
	)
);

// Featured Slider content enable control and setting
$wp_customize->add_setting( 'workart_pro_theme_options[featured_slider_section_enable]', 
	array(
		'default'			=> 	$options['featured_slider_section_enable'],
		'sanitize_callback' => 'workart_pro_sanitize_switch_control',
	) 
);

$wp_customize->add_control( new  Workart_Pro_Switch_Control( $wp_customize,
	'workart_pro_theme_options[featured_slider_section_enable]',
		array(
			'label'             => esc_html__( 'Featured Slider Section Enable', 'workart-pro' ),
			'section'           => 'workart_pro_featured_slider_section',
			'on_off_label' 		=> workart_pro_switch_options(),
		)
	)
);

// Featured Slider autoplay enable control and setting
$wp_customize->add_setting( 'workart_pro_theme_options[featured_slider_autoplay_enable]',
	array(
		'default'			=> 	$options['featured_slider_autoplay_enable'],
		'sanitize_callback' => 'workart_pro_sanitize_switch_control',
	)
);

$wp_customize->add_control( new  Workart_Pro_Switch_Control( $wp_customize,
	'workart_pro_theme_options[featured_slider_autoplay_enable]',
		array(
			'label'             => esc_html__( 'Featured Slider Autoplay Enable', 'workart-pro' ),
			'section'           => 'workart_pro_featured_slider_section',
			'active_callback'   => 'workart_pro_is_featured_slider_section_enable',
			'on_off_label' 		=> workart_pro_switch_options(),
		)
	)
);

// Featured Slider number control and setting
$wp_customize->add_setting( 'workart_pro_theme_options[featured_slider_count]',
	array(
		'default'          	=> $options['featured_slider_count'],
		'sanitize_callback' => 'workart_pro_sanitize_number_range',
		'validate_callback' => 'workart_pro_validate_featured_slider_count',
	)
);

$wp_customize->add_control( 'workart_pro_theme_options[featured_slider_count]',
	array(
		'label'             => esc_html__( 'Number of Post', 'workart-pro' ),
		'description'       => esc_html__( 'Note: Min 1 & Max 5. Please input the valid number and save. Then refresh the page to see the change.', 'workart-pro' ),
		'section'           => 'workart_pro_featured_slider_section',
		'active_callback'   => 'workart_pro_is_featured_slider_section_enable',
		'type'				=> 'number',
		'input_attrs'		=> array(
			'min'	=> 1,
			'max'	=> 5,
			'style' => 'width: 100px;'
		),
	)
);

// Featured Slider Excerpt length setting and control.
$wp_customize->add_setting( 'workart_pro_theme_options[featured_slider_excerpt_length]',
	array(
		'sanitize_callback' => 'workart_pro_sanitize_number_range',
		'default'			=> $options['featured_slider_excerpt_length'],
	)
);

$wp_customize->add_control( 'workart_pro_theme_options[featured_slider_excerpt_length]',
	array(
		'label'       		=> esc_html__( 'Excerpt Length', 'workart-pro' ),
		'description' 		=> esc_html__( 'Total words to be displayed in Featured Slider section', 'workart-pro' ),
		'section'     		=> 'workart_pro_featured_slider_section',
		'type'        		=> 'number',
		'active_callback' 	=> 'workart_pro_is_featured_slider_section_enable',
	)
);


// Featured Slider content type control and setting
$wp_customize->add_setting( 'workart_pro_theme_options[featured_slider_content_type]',
	array(
		'default'          	=> $options['featured_slider_content_type'],
		'sanitize_callback' => 'workart_pro_sanitize_select',
	)
);

$wp_customize->add_control( 'workart_pro_theme_options[featured_slider_content_type]',
	array(
		'label'             => esc_html__( 'Content Type', 'workart-pro' ),
		'section'           => 'workart_pro_featured_slider_section',
		'type'				=> 'select',
		'active_callback' 	=> 'workart_pro_is_featured_slider_section_enable',
		'choices'			=> array( 
			'page' 		=> esc_html__( 'Page', 'workart-pro' ),
			'post' 		=> esc_html__( 'Post', 'workart-pro' ),
			'category' 	=> esc_html__( 'Category', 'workart-pro' ),
		),
	)
);


for ( $i = 1; $i <= $options['featured_slider_count']; $i++ ) :

	// slider pages drop down chooser control and setting
	$wp_customize->add_setting( 'workart_pro_theme_options[featured_slider_content_page_'. $i .']', 
		array(
			'sanitize_callback' => 'workart_pro_sanitize_page',
		)
	);

	$wp_customize->add_control( new  Workart_Pro_Dropdown_Chooser( $wp_customize,
		'workart_pro_theme_options[featured_slider_content_page_'. $i .']', 
			array(
				'label'             => sprintf(esc_html__( 'Select Page: %d', 'workart-pro'), $i ),
				'section'           => 'workart_pro_featured_slider_section',
				'choices'			=> workart_pro_page_choices(),
				'active_callback'	=> 'workart_pro_is_featured_slider_section_content_page_enable',
			)
		)
	);

	// slider posts drop down chooser control and setting
	$wp_customize->add_setting( 'workart_pro_theme_options[featured_slider_content_post_'. $i .']', 
		array(
			'sanitize_callback' => 'workart_pro_sanitize_page',
		)
	);

	$wp_customize->add_control( new  Workart_Pro_Dropdown_Chooser( $wp_customize,
		'workart_pro_theme_options[featured_slider_content_post_'. $i .']',
			array(
				'label'             => sprintf(esc_html__( 'Select Post : %d', 'workart-pro'), $i ),
				'section'           => 'workart_pro_featured_slider_section',
				'choices'			=> workart_pro_post_choices(),
				'active_callback'	=> 'workart_pro_is_featured_slider_section_content_post_enable',
			)
		)
	);

	// Workart_Pro_Customize_Horizontal_Line
    $wp_customize->add_setting('workart_pro_theme_options[featured_slider_separator'. $i .']',
		array(
			'sanitize_callback'      => 'workart_pro_sanitize_html',
		)
	);

    $wp_customize->add_control(new Workart_Pro_Customize_Horizontal_Line($wp_customize,
		'workart_pro_theme_options[featured_slider_separator'. $i .']',
			array(
				'active_callback'       => 'workart_pro_is_featured_slider_section_separator_enable',
				'type'                  =>'hr',
				'section'               =>'workart_pro_featured_slider_section',
			)
		)
	);

endfor;

// slider posts drop down chooser control and setting
$wp_customize->add_setting( 'workart_pro_theme_options[featured_slider_category]',
	array(
		'sanitize_callback' => 'workart_pro_sanitize_single_category',
	)
);

$wp_customize->add_control( new  Workart_Pro_Dropdown_Taxonomies_Control( $wp_customize,
	'workart_pro_theme_options[featured_slider_category]', 
		array(
			'label'             => esc_html__( 'Select Categories', 'workart-pro' ),
			'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'workart-pro' ),
			'type'           	=> 'dropdown-taxonomies',
			'section'           => 'workart_pro_featured_slider_section',
			'active_callback'	=> 'workart_pro_is_featured_slider_section_content_category_enable',
		)
	)
); 

//featured_slider_btn_txt
$wp_customize->add_setting('workart_pro_theme_options[featured_slider_btn_txt]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['featured_slider_btn_txt'],
    )
);

$wp_customize->add_control('workart_pro_theme_options[featured_slider_btn_txt]',
    array(
        'section'			=> 'workart_pro_featured_slider_section',
        'label'				=> esc_html__( 'Button Text:', 'workart-pro' ),
        'type'          	=>'text',
        'active_callback' 	=> 'workart_pro_is_featured_slider_section_enable'
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'workart_pro_theme_options[featured_slider_btn_txt]',
		array(
			'selector'            => '#featured-slider article div.read-more a:nth-child(1)',
			'settings'            => 'workart_pro_theme_options[featured_slider_btn_txt]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'workart_pro_featured_slider_btn_txt_partial',
		) 
	);
}

//featured_slider_btn_alt_txt
$wp_customize->add_setting('workart_pro_theme_options[featured_slider_btn_alt_txt]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['featured_slider_btn_alt_txt'],
    )
);

$wp_customize->add_control('workart_pro_theme_options[featured_slider_btn_alt_txt]',
    array(
        'section'			=> 'workart_pro_featured_slider_section',
        'label'				=> esc_html__( 'Button Text:', 'workart-pro' ),
        'type'          	=>'text',
        'active_callback' 	=> 'workart_pro_is_featured_slider_section_enable'
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'workart_pro_theme_options[featured_slider_btn_alt_txt]',
		array(
			'selector'            => '#featured-slider div.read-more a:nth-child(2)',
			'settings'            => 'workart_pro_theme_options[featured_slider_btn_alt_txt]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'workart_pro_featured_slider_btn_alt_txt_partial',
		) 
	);
}

$wp_customize->add_setting( 'workart_pro_theme_options[featured_slider_btn_alt_url]',
    array(
        'sanitize_callback' => 'esc_url_raw',
    )
);

$wp_customize->add_control( 'workart_pro_theme_options[featured_slider_btn_alt_url]',
    array(
        'label'           	=> esc_html__( 'Button Alt URL', 'workart-pro' ),
        'section'        	=> 'workart_pro_featured_slider_section',
        'active_callback' 	=> 'workart_pro_is_featured_slider_section_enable',
        'type'				=> 'url',
    ) 
);
