<?php
/**
 * Latest Post Section options
 *
 * @package Theme Palace
 * @subpackage Workart Pro
 * @since Workart Pro 1.0.0
 */

// Add Latest Post section
$wp_customize->add_section( 'workart_pro_latest_posts_section',
    array(
        'title'             => esc_html__( 'Latest Post','workart-pro' ),
        'description'       => esc_html__( 'Latest Post Section options.', 'workart-pro' ),
        'panel'             => 'workart_pro_front_page_panel',
    )
);

// Latest Post content enable control and setting
$wp_customize->add_setting( 'workart_pro_theme_options[latest_posts_section_enable]',
    array(
        'default'           =>  $options['latest_posts_section_enable'],
        'sanitize_callback' => 'workart_pro_sanitize_switch_control',
    )
);

$wp_customize->add_control( new Workart_Pro_Switch_Control( $wp_customize,
    'workart_pro_theme_options[latest_posts_section_enable]',
        array(
            'label'             => esc_html__( 'Latest Post Section Enable', 'workart-pro' ),
            'section'           => 'workart_pro_latest_posts_section',
            'on_off_label'      => workart_pro_switch_options(),
        ) 
    )
);

// latest_post section sub title control and setting
$wp_customize->add_setting('workart_pro_theme_options[latest_posts_sub_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport' => 'postMessage',
        'default'  => $options['latest_posts_sub_title'],
    )
);

$wp_customize->add_control('workart_pro_theme_options[latest_posts_sub_title]',
    array(
        'label' => esc_html__('Section Sub Title', 'workart-pro'),
        'section' => 'workart_pro_latest_posts_section',
        'type' => 'text',
        'active_callback' => 'workart_pro_is_latest_posts_section_enable',
    )
);

$wp_customize->selective_refresh->add_partial('workart_pro_theme_options[latest_posts_sub_title]',
    array(
        'selector' => '#workart_pro_latest_posts_section .section-subtitle',
        'render_callback' => 'workart_pro_latest_posts_sub_title_partial',
    )
);

// latest_post title setting and control
$wp_customize->add_setting( 'workart_pro_theme_options[latest_posts_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['latest_posts_title'],
        'transport'         => 'postMessage',
    )
);

$wp_customize->add_control( 'workart_pro_theme_options[latest_posts_title]',
    array(
        'label'             => esc_html__( 'Section Title', 'workart-pro' ),
        'section'           => 'workart_pro_latest_posts_section',
        'active_callback'   => 'workart_pro_is_latest_posts_section_enable',
        'type'              => 'text',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'workart_pro_theme_options[latest_posts_title]',
        array(
            'selector'            => '#workart_pro_latest_posts_section .section-header h2',
            'settings'            => 'workart_pro_theme_options[latest_posts_title]',
            'container_inclusive' => false,
            'fallback_refresh'    => true,
            'render_callback'     => 'workart_pro_latest_posts_title_partial',
        )
    );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'workart_pro_theme_options[latest_posts_count]',
    array(
        'default'           => $options['latest_posts_count'],
        'sanitize_callback' => 'workart_pro_sanitize_number_range',
        'validate_callback' => 'workart_pro_validate_latest_posts_count',
    )
);

$wp_customize->add_control( 'workart_pro_theme_options[latest_posts_count]',
    array(
        'label'             => esc_html__( 'Number of Posts', 'workart-pro' ),
        'description'       => esc_html__( 'Note: Min 2 & Max 9. Please input the valid number and save. Then refresh the page to see the change.', 'workart-pro' ),
        'section'           => 'workart_pro_latest_posts_section',
        'active_callback'   => 'workart_pro_is_latest_posts_section_enable',
        'type'              => 'number',
        'input_attrs'       => array(
            'min'   => 2,
            'max'   => 9,
            'style' => 'width: 100px;'
        ),
    )
);

// Latest Post content type control and setting
$wp_customize->add_setting( 'workart_pro_theme_options[latest_posts_content_type]',
    array(
        'default'           => $options['latest_posts_content_type'],
        'sanitize_callback' => 'workart_pro_sanitize_select',
    )
);

$wp_customize->add_control( 'workart_pro_theme_options[latest_posts_content_type]',
    array(
        'label'             => esc_html__( 'Content Type', 'workart-pro' ),
        'section'           => 'workart_pro_latest_posts_section',
        'type'              => 'select',
        'active_callback'   => 'workart_pro_is_latest_posts_section_enable',
        'choices'           => array( 
            'page'      => esc_html__( 'Page', 'workart-pro' ),
            'post'      => esc_html__( 'Post', 'workart-pro' ),
            'category'  => esc_html__( 'Category', 'workart-pro' ),
            'recent'    => esc_html__( 'Recent', 'workart-pro' ),
        ),
    ) 
);

for ( $i = 1; $i <= $options['latest_posts_count']; $i++ ) :

    // latest_post pages drop down chooser control and setting
    $wp_customize->add_setting( 'workart_pro_theme_options[latest_posts_content_page_' . $i . ']',
        array(
            'sanitize_callback' => 'workart_pro_sanitize_page',
        )
    );

    $wp_customize->add_control( new Workart_Pro_Dropdown_Chooser( $wp_customize,
        'workart_pro_theme_options[latest_posts_content_page_' . $i . ']',
            array(
                'label'             => sprintf( esc_html__( 'Select Page %d', 'workart-pro' ), $i ),
                'section'           => 'workart_pro_latest_posts_section',
                'choices'           => workart_pro_page_choices(),
                'active_callback'   => 'workart_pro_is_latest_posts_section_content_page_enable',
            )
        )
    );

    // latest_post posts drop down chooser control and setting
    $wp_customize->add_setting( 'workart_pro_theme_options[latest_posts_content_post_' . $i . ']',
        array(
            'sanitize_callback' => 'workart_pro_sanitize_page',
        )
    );

    $wp_customize->add_control( new Workart_Pro_Dropdown_Chooser( $wp_customize,
        'workart_pro_theme_options[latest_posts_content_post_' . $i . ']',
            array(
                'label'             => sprintf( esc_html__( 'Select Post %d', 'workart-pro' ), $i ),
                'section'           => 'workart_pro_latest_posts_section',
                'choices'           => workart_pro_post_choices(),
                'active_callback'   => 'workart_pro_is_latest_posts_section_content_post_enable',
            ) 
        )
    );

    //latest_post separator
    $wp_customize->add_setting('workart_pro_theme_options[latest_posts_separator'. $i .']',
        array(
            'sanitize_callback'      => 'workart_pro_sanitize_html',
        )
    );

    $wp_customize->add_control(new Workart_Pro_Customize_Horizontal_Line($wp_customize,
        'workart_pro_theme_options[latest_posts_separator'. $i .']',
            array(
                'active_callback'       => 'workart_pro_is_latest_posts_section_separator_enable',
                'type'                  =>'hr',
                'section'               =>'workart_pro_latest_posts_section',
            )
        )
    );
    
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'workart_pro_theme_options[latest_posts_content_category]',
    array(
        'sanitize_callback' => 'workart_pro_sanitize_single_category',
    )
);

$wp_customize->add_control( new Workart_Pro_Dropdown_Taxonomies_Control( $wp_customize,
    'workart_pro_theme_options[latest_posts_content_category]',
        array(
            'label'             => esc_html__( 'Select Category', 'workart-pro' ),
            'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'workart-pro' ),
            'section'           => 'workart_pro_latest_posts_section',
            'type'              => 'dropdown-taxonomies',
            'active_callback'   => 'workart_pro_is_latest_posts_section_content_category_enable'
        )
    )
);

// Add dropdown categories setting and control.
$wp_customize->add_setting( 'workart_pro_theme_options[latest_posts_category_exclude]',
    array(
        'sanitize_callback' => 'workart_pro_sanitize_category_list',
    )
);

$wp_customize->add_control( new Workart_Pro_Dropdown_Multiple_Chooser( $wp_customize,
    'workart_pro_theme_options[latest_posts_category_exclude]',
        array(
            'label'             => esc_html__( 'Select Excluding Categories', 'workart-pro' ),
            'section'           => 'workart_pro_latest_posts_section',
            'type'              => 'dropdown_multiple_chooser',
            'choices'           =>  workart_pro_category_choices(),
            'active_callback'   => 'workart_pro_is_latest_posts_section_content_recent_enable'
        )
    )
);

// Popular Post Read More content setting
$wp_customize->add_setting('workart_pro_theme_options[latest_posts_read_more_btn_label]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['latest_posts_read_more_btn_label']

    )
);

$wp_customize->add_control('workart_pro_theme_options[latest_posts_read_more_btn_label]',
    array(
        'section'			=> 'workart_pro_latest_posts_section',
        'label'				=> esc_html__( 'Read More Button Label', 'workart-pro' ),
        'type'          	=>'text',
        'active_callback'	=> 'workart_pro_is_latest_posts_section_enable'
    )
);


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'workart_pro_theme_options[latest_posts_read_more_btn_label]',
        array(
            'selector'            => '#workart_pro_latest_posts_section div.read-more a',
            'settings'            => 'workart_pro_theme_options[latest_posts_read_more_btn_label]',
            'fallback_refresh'    => true,
            'container_inclusive' => false,
            'render_callback'     => 'workart_pro_latest_posts_read_more_btn_label_partial',
        ) 
    );
}

// latest_post content type control and setting
$wp_customize->add_setting( 'workart_pro_theme_options[latest_posts_column]',
    array(
        'default'          	=> $options['latest_posts_column'],
        'sanitize_callback' => 'workart_pro_sanitize_select',
    )
);

$wp_customize->add_control( 'workart_pro_theme_options[latest_posts_column]',
    array(
        'label'             => esc_html__( 'Column Layout', 'workart-pro' ),
        'section'           => 'workart_pro_latest_posts_section',
        'type'				=> 'select',
        'active_callback' 	=> 'workart_pro_is_latest_posts_section_enable',
        'choices'			=> array( 
            'col-1'		=> esc_html__( 'One Column', 'workart-pro' ),
            'col-2'		=> esc_html__( 'Two Column', 'workart-pro' ),
            'col-3'		=> esc_html__( 'Three Column', 'workart-pro' ),
            'col-4'		=> esc_html__( 'Four Column', 'workart-pro' ),
        ),
    )
);