<?php
/**
 * Latest Product Section options
 *
 * @package Theme Palace
 * @subpackage Workart Pro
 * @since Workart Pro 1.0.0
 */
if ( !class_exists('WooCommerce') ) {
    return;
}
// Add Product section
$wp_customize->add_section( 'workart_pro_latest_products_section',
	array(
		'title'             => esc_html__( 'Latest Product','workart-pro' ),
		'description'       => esc_html__( 'Note: To activate this section you need to install WooCommerce Plugin.', 'workart-pro' ),
		'panel'             => 'workart_pro_front_page_panel',
		'active_callback'	=> function( $control ) {
			return (
				workart_pro_is_pro_layout( $control )
				||
				workart_pro_is_fourth_layout( $control )
			);
		},
	)
);

// Product content enable control and setting
$wp_customize->add_setting( 'workart_pro_theme_options[latest_products_section_enable]',
	array(
		'default'			=> 	$options['latest_products_section_enable'],
		'sanitize_callback' => 'workart_pro_sanitize_switch_control',
	)
);

$wp_customize->add_control( new Workart_Pro_Switch_Control( $wp_customize,
	'workart_pro_theme_options[latest_products_section_enable]',
		array(
			'label'             => esc_html__( 'Latest Product Section Enable', 'workart-pro' ),
			'section'           => 'workart_pro_latest_products_section',
			'on_off_label' 		=> workart_pro_switch_options(),
		)
	)
);


for ( $i = 1; $i <= 2; $i++ ) :

		// Workart_Pro_Customize_Horizontal_Line
	$wp_customize->add_setting('workart_pro_theme_options[latest_products_separator'. $i .']',
		array(
			'sanitize_callback'      => 'workart_pro_sanitize_html',
		)
	);

    $wp_customize->add_control(new Workart_Pro_Customize_Horizontal_Line($wp_customize,
		'workart_pro_theme_options[latest_products_separator'. $i .']',
			array(
				'type'                  => 'hr',
				'section'               => 'workart_pro_latest_products_section',
				'active_callback'       => 'workart_pro_is_latest_products_section_enable'
			)
		)
	);

	// Add dropdown category setting and control.
	$wp_customize->add_setting(  'workart_pro_theme_options[latest_products_content_product_category_'.$i.']',
		array(
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control( new Workart_Pro_Dropdown_Taxonomies_Control( $wp_customize,
		'workart_pro_theme_options[latest_products_content_product_category_'.$i.']', 
			array(
                'label'             => sprintf( esc_html__( 'Select Product Category %d', 'workart-pro' ), $i ),
				'section'           => 'workart_pro_latest_products_section',
				'taxonomy'			=> 'product_cat',
				'type'              => 'dropdown-taxonomies',
				'active_callback'	=> 'workart_pro_is_latest_products_section_enable'
			)
		)
	);
	
endfor;

