<?php
/**
 * Our Partners Section options
 *
 * @package Theme Palace
 * @subpackage  Workart Pro
 * @since  Workart Pro 1.0.0
 */

// Add Our Partners section
$wp_customize->add_section( 'workart_pro_our_partners_section',
	array(
		'title'             => esc_html__( 'Our Partners','workart-pro' ),
		'description'       => esc_html__( 'Our Partners Section options.', 'workart-pro' ),
		'panel'             => 'workart_pro_front_page_panel',
		'active_callback'	=> function( $control ) {
            return (
                workart_pro_is_pro_layout( $control )
                ||
                workart_pro_is_second_layout( $control )
                ||
                workart_pro_is_fourth_layout( $control )
            );
        },
	)
);

// Our Partners content enable control and setting
$wp_customize->add_setting( 'workart_pro_theme_options[our_partners_section_enable]', 
	array(
		'default'			=> 	$options['our_partners_section_enable'],
		'sanitize_callback' => 'workart_pro_sanitize_switch_control',
	) 
);

$wp_customize->add_control( new  Workart_Pro_Switch_Control( $wp_customize,
	'workart_pro_theme_options[our_partners_section_enable]',
		array(
			'label'             => esc_html__( 'Our Partners Section Enable', 'workart-pro' ),
			'section'           => 'workart_pro_our_partners_section',
			'on_off_label' 		=> workart_pro_switch_options(),
		)
	)
);

// Our Partners number control and setting
$wp_customize->add_setting( 'workart_pro_theme_options[our_partners_count]',
	array(
		'default'          	=> $options['our_partners_count'],
		'sanitize_callback' => 'workart_pro_sanitize_number_range',
		'validate_callback' => 'workart_pro_validate_our_partners_count',
	)
);

$wp_customize->add_control( 'workart_pro_theme_options[our_partners_count]',
	array(
		'label'             => esc_html__( 'Number of Post', 'workart-pro' ),
		'description'       => esc_html__( 'Note: Min 1 & Max 5. Please input the valid number and save. Then refresh the page to see the change.', 'workart-pro' ),
		'section'           => 'workart_pro_our_partners_section',
		'active_callback'   => 'workart_pro_is_our_partners_section_enable',
		'type'				=> 'number',
		'input_attrs'		=> array(
			'min'	=> 1,
			'max'	=> 5,
			'style' => 'width: 100px;'
		),
	)
);

// Our Partners content type control and setting
$wp_customize->add_setting( 'workart_pro_theme_options[our_partners_content_type]',
	array(
		'default'          	=> $options['our_partners_content_type'],
		'sanitize_callback' => 'workart_pro_sanitize_select',
	)
);

$wp_customize->add_control( 'workart_pro_theme_options[our_partners_content_type]',
	array(
		'label'             => esc_html__( 'Content Type', 'workart-pro' ),
		'section'           => 'workart_pro_our_partners_section',
		'type'				=> 'select',
		'active_callback' 	=> 'workart_pro_is_our_partners_section_enable',
		'choices'			=> array( 
			'page' 		=> esc_html__( 'Page', 'workart-pro' ),
			'post' 		=> esc_html__( 'Post', 'workart-pro' ),
			'category' 	=> esc_html__( 'Category', 'workart-pro' ),
			'custom' 	=> esc_html__( 'Custom', 'workart-pro' ),
		),
	)
);


for ( $i = 1; $i <= $options['our_partners_count']; $i++ ) :

	// sponsor pages drop down chooser control and setting
	$wp_customize->add_setting( 'workart_pro_theme_options[our_partners_content_page_'. $i .']', 
		array(
			'sanitize_callback' => 'workart_pro_sanitize_page',
		)
	);

	$wp_customize->add_control( new  Workart_Pro_Dropdown_Chooser( $wp_customize,
		'workart_pro_theme_options[our_partners_content_page_'. $i .']', 
			array(
				'label'             => sprintf(esc_html__( 'Select Page: %d', 'workart-pro'), $i ),
				'section'           => 'workart_pro_our_partners_section',
				'choices'			=> workart_pro_page_choices(),
				'active_callback'	=> 'workart_pro_is_our_partners_section_content_page_enable',
			)
		)
	);

	// sponsor posts drop down chooser control and setting
	$wp_customize->add_setting( 'workart_pro_theme_options[our_partners_content_post_'. $i .']', 
		array(
			'sanitize_callback' => 'workart_pro_sanitize_page',
		)
	);

	$wp_customize->add_control( new  Workart_Pro_Dropdown_Chooser( $wp_customize,
		'workart_pro_theme_options[our_partners_content_post_'. $i .']',
			array(
				'label'             => sprintf(esc_html__( 'Select Post : %d', 'workart-pro'), $i ),
				'section'           => 'workart_pro_our_partners_section',
				'choices'			=> workart_pro_post_choices(),
				'active_callback'	=> 'workart_pro_is_our_partners_section_content_post_enable',
			)
		)
	);

	// Workart_Pro_Customize_Horizontal_Line
    $wp_customize->add_setting('workart_pro_theme_options[our_partners_separator'. $i .']',
		array(
			'sanitize_callback'      => 'workart_pro_sanitize_html',
		)
	);

    $wp_customize->add_control(new Workart_Pro_Customize_Horizontal_Line($wp_customize,
		'workart_pro_theme_options[our_partners_separator'. $i .']',
			array(
				'active_callback'       => 'workart_pro_is_our_partners_section_separator_enable',
				'type'                  =>'hr',
				'section'               =>'workart_pro_our_partners_section',
			)
		)
	);

        
    // About image setting
    $wp_customize->add_setting('workart_pro_theme_options[our_partners_image_'.$i.']',
		array(
			'sanitize_callback' => 'workart_pro_sanitize_image',
		)
	);

    $wp_customize->add_control(new WP_Customize_Image_Control( $wp_customize,
		'workart_pro_theme_options[our_partners_image_'.$i.']',
			array(
				'section'			=> 'workart_pro_our_partners_section',
				'label'				=> esc_html__( 'Image:', 'workart-pro' ),
				'active_callback' 	=> 'workart_pro_is_our_partners_section_content_custom_enable',
			)
		)
	);

            
    $wp_customize->add_setting( 'workart_pro_theme_options[our_partners_url_'.$i.']',
        array(
            'sanitize_callback' => 'esc_url_raw',
        )
    );

    $wp_customize->add_control( 'workart_pro_theme_options[our_partners_url_'.$i.']',
        array(
			'label'             => sprintf(esc_html__( 'Our Partners URL : %d', 'workart-pro'), $i ),
            'section'        	=> 'workart_pro_our_partners_section',
            'active_callback' 	=> 'workart_pro_is_our_partners_section_content_custom_enable',
            'type'				=> 'url',
        ) 
    );

endfor;

// sponsor posts drop down chooser control and setting
$wp_customize->add_setting( 'workart_pro_theme_options[our_partners_category]',
	array(
		'sanitize_callback' => 'workart_pro_sanitize_single_category',
	)
);

$wp_customize->add_control( new  Workart_Pro_Dropdown_Taxonomies_Control( $wp_customize,
	'workart_pro_theme_options[our_partners_category]', 
		array(
			'label'             => esc_html__( 'Select Categories', 'workart-pro' ),
			'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'workart-pro' ),
			'type'           	=> 'dropdown-taxonomies',
			'section'           => 'workart_pro_our_partners_section',
			'active_callback'	=> 'workart_pro_is_our_partners_section_content_category_enable',
		)
	)
); 

