<?php
/**
 * Service Section options
 *
 * @package Theme Palace
 * @subpackage  Workart Pro
 * @since  Workart Pro 1.0.0
 */

// Add Service section
$wp_customize->add_section( 'workart_pro_our_services_section', 
	array(
		'title'             => esc_html__( 'Our Services','workart-pro' ),
		'description'       => esc_html__( 'Our Services Section options.', 'workart-pro' ),
		'panel'             => 'workart_pro_front_page_panel',
		'active_callback'	=> function( $control ) {
            return (
                workart_pro_is_pro_layout( $control )
                ||
                workart_pro_is_default_layout( $control )
                ||
                workart_pro_is_second_layout( $control )
                ||
                workart_pro_is_fourth_layout( $control )
            );
        },
	) 
);

// Service content enable control and setting
$wp_customize->add_setting( 'workart_pro_theme_options[our_services_section_enable]', 
	array(
		'default'			=> 	$options['our_services_section_enable'],
		'sanitize_callback' => 'workart_pro_sanitize_switch_control',
	) 
);

$wp_customize->add_control( new  Workart_Pro_Switch_Control( $wp_customize,
	'workart_pro_theme_options[our_services_section_enable]', 
		array(
			'label'             => esc_html__( 'Our Services Section Enable', 'workart-pro' ),
			'section'           => 'workart_pro_our_services_section',
			'on_off_label' 		=> workart_pro_switch_options(),
		) 
	)
);


// Service section sub title control and setting
$wp_customize->add_setting( 'workart_pro_theme_options[our_services_section_sub_title]', 
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'transport'			=>'postMessage',
		'default'           => $options['our_services_section_sub_title'],
	) 
);

$wp_customize->add_control('workart_pro_theme_options[our_services_section_sub_title]', 
	array(
		'label'             => esc_html__( 'Section Sub Title', 'workart-pro' ),
		'section'           => 'workart_pro_our_services_section',
		'type'              =>'text',
		'active_callback'	=> 'workart_pro_is_our_services_section_enable',
	)
);

$wp_customize->selective_refresh->add_partial('workart_pro_theme_options[our_services_section_sub_title]',
    array(
        'selector'            => '#workart_pro_our_services_section .section-subtitle',
        'render_callback'     => 'workart_pro_our_services_section_partial_sub_title',
    )
);

// Service section title control and setting
$wp_customize->add_setting( 'workart_pro_theme_options[our_services_section_title]', 
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'transport'			=>'postMessage',
		'default'           => $options['our_services_section_title'],
		
	) 
);

$wp_customize->add_control('workart_pro_theme_options[our_services_section_title]', 
	array(
		'label'             => esc_html__( 'Section Title', 'workart-pro' ),
		'section'           => 'workart_pro_our_services_section',
		'type'              =>'text',
		'active_callback'	=> 'workart_pro_is_our_services_section_enable',
	)
);
$wp_customize->selective_refresh->add_partial(
    'workart_pro_theme_options[our_services_section_title]',
    array(
        'selector'            => '#workart_pro_our_services_section .section-title',
        'render_callback'     => 'workart_pro_our_services_section_partial_title',
    )
);

// Service content type control and setting
$wp_customize->add_setting( 'workart_pro_theme_options[our_services_content_type]',
	array(
		'default'          	=> $options['our_services_content_type'],
		'sanitize_callback' => 'workart_pro_sanitize_select',
	) 
);

$wp_customize->add_control( 'workart_pro_theme_options[our_services_content_type]',
	array(
		'label'             => esc_html__( 'Content Type', 'workart-pro' ),
		'section'           => 'workart_pro_our_services_section',
		'type'				=> 'select',
		'active_callback' 	=> 'workart_pro_is_our_services_section_enable',
		'choices'			=> array( 
			'page' 		=> esc_html__( 'Page', 'workart-pro' ),
			'post' 		=> esc_html__( 'Post', 'workart-pro' ),
			'category' 	=> esc_html__( 'Category', 'workart-pro' ),
		),
	) 
);

// Our Services post number control and setting
$wp_customize->add_setting( 'workart_pro_theme_options[our_services_posts_count]', 
	array(
		'default'          	=> $options['our_services_posts_count'],
		'sanitize_callback' => 'workart_pro_sanitize_number_range',
		'validate_callback' => 'workart_pro_validate_our_services_posts_count',
	)
);

$wp_customize->add_control( 'workart_pro_theme_options[our_services_posts_count]', 
	array(
		'label'             => esc_html__( 'Number of Posts', 'workart-pro' ),
		'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'workart-pro' ),
		'section'           => 'workart_pro_our_services_section',
		'active_callback'   => 'workart_pro_is_our_services_section_enable',
		'type'				=> 'number',
		'input_attrs'		=> array(
			'min'	=> 1,
			'max'	=> 12,
			'style' => 'width: 100px;'
		),
	) 
);

for($i = 1; $i <= $options['our_services_posts_count']; $i ++):
		
    $wp_customize->add_setting( 'workart_pro_theme_options[our_services_icon_' . $i . ']', 
        array(
            'sanitize_callback' => 'sanitize_text_field',
        )
    );

	$wp_customize->add_control( new Workart_Pro_Icon_Picker( $wp_customize,
		'workart_pro_theme_options[our_services_icon_' . $i . ']',
			array(
				'label'             => sprintf( esc_html__( 'Service Icon %d', 'workart-pro' ), $i ),
				'section'           => 'workart_pro_our_services_section',
				'active_callback'	=> 'workart_pro_is_our_services_section_enable',
			)
		)
	);

    // service pages drop down chooser control and setting
	$wp_customize->add_setting( 'workart_pro_theme_options[our_services_content_page_'.$i.']',
		array(
			'sanitize_callback' => 'workart_pro_sanitize_page',
		) 
	);

	$wp_customize->add_control( new  Workart_Pro_Dropdown_Chooser( $wp_customize,
		'workart_pro_theme_options[our_services_content_page_'.$i.']',
			array(
				'label'             => sprintf(esc_html__( 'Select Page : %d', 'workart-pro'), $i ),
				'section'           => 'workart_pro_our_services_section',
				'choices'			=> workart_pro_page_choices(),
				'active_callback'	=> 'workart_pro_is_our_services_section_content_page_enable',
			) 
		)
	);

	// service posts drop down chooser control and setting
	$wp_customize->add_setting( 'workart_pro_theme_options[our_services_content_post_'.$i.']', 
		array(
			'sanitize_callback' => 'workart_pro_sanitize_page',
		) 
	);

	$wp_customize->add_control( new  Workart_Pro_Dropdown_Chooser( $wp_customize,
		'workart_pro_theme_options[our_services_content_post_'.$i.']', 
			array(
				'label'             => sprintf(esc_html__( 'Select Post : %d', 'workart-pro'), $i ),
				'section'           => 'workart_pro_our_services_section',
				'choices'			=> workart_pro_post_choices(),
				'active_callback'	=> 'workart_pro_is_our_services_section_content_post_enable',
			)
		)
	);

    // Workart_Pro_Customize_Horizontal_Line
    $wp_customize->add_setting('workart_pro_theme_options[our_services_separator'. $i .']',
		array(
			'sanitize_callback'      => 'workart_pro_sanitize_html',
		)
	);

    $wp_customize->add_control(new  Workart_Pro_Customize_Horizontal_Line($wp_customize,
		'workart_pro_theme_options[our_services_separator'. $i .']',
			array(
				'active_callback'       => 'workart_pro_is_our_services_section_enable',
				'type'                  =>'hr',
				'section'               =>'workart_pro_our_services_section',
			)
		)
	);

endfor;

// service category drop down chooser control and setting
$wp_customize->add_setting( 'workart_pro_theme_options[our_services_category]', 
	array(
		'sanitize_callback' => 'workart_pro_sanitize_single_category',
	)
);

$wp_customize->add_control( new  Workart_Pro_Dropdown_Taxonomies_Control( $wp_customize,
	'workart_pro_theme_options[our_services_category]',
		array(
			'label'             => esc_html__( 'Select Categories', 'workart-pro' ),
			'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'workart-pro' ),
			'type'           	=> 'dropdown-taxonomies',
			'section'           => 'workart_pro_our_services_section',
			'active_callback'	=> 'workart_pro_is_our_services_section_content_category_enable',
		) 
	)
);

// Service Excerpt length setting and control.
$wp_customize->add_setting( 'workart_pro_theme_options[our_services_excerpt_length]',
	array(
		'sanitize_callback' => 'workart_pro_sanitize_number_range',
		'default'			=> $options['our_services_excerpt_length'],
	)
);

$wp_customize->add_control( 'workart_pro_theme_options[our_services_excerpt_length]',
	array(
		'label'       		=> esc_html__( 'Excerpt Length', 'workart-pro' ),
		'description' 		=> esc_html__( 'Total words to be displayed in Service section', 'workart-pro' ),
		'section'     		=> 'workart_pro_our_services_section',
		'type'        		=> 'number',
		'active_callback' 	=> 'workart_pro_is_our_services_section_enable',
	)
);

// our_services content type control and setting
$wp_customize->add_setting( 'workart_pro_theme_options[our_services_column]',
    array(
        'default'          	=> $options['our_services_column'],
        'sanitize_callback' => 'workart_pro_sanitize_select',
    )
);

$wp_customize->add_control( 'workart_pro_theme_options[our_services_column]',
    array(
        'label'             => esc_html__( 'Column Layout', 'workart-pro' ),
        'section'           => 'workart_pro_our_services_section',
        'type'				=> 'select',
        'active_callback' 	=> 'workart_pro_is_our_services_section_enable',
        'choices'			=> array( 
            'col-1'		=> esc_html__( 'One Column', 'workart-pro' ),
            'col-2'		=> esc_html__( 'Two Column', 'workart-pro' ),
            'col-3'		=> esc_html__( 'Three Column', 'workart-pro' ),
            'col-4'		=> esc_html__( 'Four Column', 'workart-pro' ),
        ),
    )
);