<?php
/**
 * Popular Product Section options
 *
 * @package Theme Palace
 * @subpackage Workart Pro
 * @since Workart Pro 1.0.0
 */
if ( !class_exists('WooCommerce') ) {
    return;
}
// Add Product section
$wp_customize->add_section( 'workart_pro_popular_products_section',
	array(
		'title'             => esc_html__( 'Popular Product','workart-pro' ),
		'description'       => esc_html__( 'Note: To activate this section you need to install WooCommerce Plugin.', 'workart-pro' ),
        'panel'       		=> 'workart_pro_front_page_panel',
		'active_callback'	=> function( $control ) {
			return (
				workart_pro_is_pro_layout( $control )
				||
				workart_pro_is_fourth_layout( $control )
			);
		},
	)
);

// Product content enable control and setting
$wp_customize->add_setting( 'workart_pro_theme_options[popular_products_section_enable]',
	array(
		'default'			=> 	$options['popular_products_section_enable'],
		'sanitize_callback' => 'workart_pro_sanitize_switch_control',
	)
);

$wp_customize->add_control( new Workart_Pro_Switch_Control( $wp_customize,
	'workart_pro_theme_options[popular_products_section_enable]',
		array(
			'label'             => esc_html__( 'Popular Product Section Enable', 'workart-pro' ),
			'section'           => 'workart_pro_popular_products_section',
			'on_off_label' 		=> workart_pro_switch_options(),
		)
	)
);

// popular_product title setting and control
$wp_customize->add_setting( 'workart_pro_theme_options[popular_products_sub_title]',
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> $options['popular_products_sub_title'],
		'transport'			=> 'postMessage',
	)
);

$wp_customize->add_control( 'workart_pro_theme_options[popular_products_sub_title]',
	array(
		'label'           	=> esc_html__( 'Section Sub Title', 'workart-pro' ),
		'section'        	=> 'workart_pro_popular_products_section',
		'active_callback' 	=> 'workart_pro_is_popular_products_section_enable',
		'type'				=> 'text',
	)
);


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'workart_pro_theme_options[popular_products_sub_title]',
		array(
			'selector'            => '#workart_pro_popular_products_section .section-header p.section-subtitle',
			'settings'            => 'workart_pro_theme_options[popular_products_sub_title]',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'workart_pro_popular_products_sub_title_partial',
		)
	);
}

// popular_product title setting and control
$wp_customize->add_setting( 'workart_pro_theme_options[popular_products_title]',
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> $options['popular_products_title'],
		'transport'			=> 'postMessage',
	)
);

$wp_customize->add_control( 'workart_pro_theme_options[popular_products_title]',
	array(
		'label'           	=> esc_html__( 'Section Title', 'workart-pro' ),
		'section'        	=> 'workart_pro_popular_products_section',
		'active_callback' 	=> 'workart_pro_is_popular_products_section_enable',
		'type'				=> 'text',
	)
);


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'workart_pro_theme_options[popular_products_title]',
		array(
			'selector'            => '#workart_pro_popular_products_section .section-header h2.section-title',
			'settings'            => 'workart_pro_theme_options[popular_products_title]',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'workart_pro_popular_products_title_partial',
		)
	);
}

// Product content type control and setting
$wp_customize->add_setting( 'workart_pro_theme_options[popular_products_content_type]',
	array(
		'default'          	=> $options['popular_products_content_type'],
		'sanitize_callback' => 'workart_pro_sanitize_select',
	)
);

$wp_customize->add_control( 'workart_pro_theme_options[popular_products_content_type]',
	array(
		'label'             => esc_html__( 'Content Type', 'workart-pro' ),
		'section'           => 'workart_pro_popular_products_section',
		'type'				=> 'select',
		'active_callback' 	=> 'workart_pro_is_popular_products_section_enable',
		'choices'			=>  array(
			'product'            => esc_html__( 'Product', 'workart-pro' ),
			'product-category'   => esc_html__( 'Product Category', 'workart-pro' ),
		)
	)
);

// Event social icons number control and setting
$wp_customize->add_setting( 'workart_pro_theme_options[popular_products_count]',
	array(
		'default'          	=> $options['popular_products_count'],
		'sanitize_callback' => 'workart_pro_sanitize_number_range',
		'validate_callback' => 'workart_pro_validate_popular_products_count',
	)
);

$wp_customize->add_control( 'workart_pro_theme_options[popular_products_count]',
	array(
		'label'             => esc_html__( 'Number of Product', 'workart-pro' ),
		'description'       => esc_html__( 'Note: Min 1 & Max 8. Please input the valid number and save. Then refresh the page to see the change.', 'workart-pro' ),
		'section'           => 'workart_pro_popular_products_section',
		'active_callback'   => 'workart_pro_is_popular_products_section_enable',
		'type'				=> 'number',
		'input_attrs'		=> array(
			'min'	=> 1,
			'max'	=> 8,
			'style' => 'width: 100px;'
		),
	)
);

for( $i = 1 ; $i <= $options['popular_products_count'] ; $i++ ){

    $wp_customize->add_setting( 'workart_pro_theme_options[popular_products_content_product_' . $i . ']',
        array(
            'sanitize_callback' => 'workart_pro_sanitize_page',
        )
    );

    $wp_customize->add_control( new Workart_Pro_Dropdown_Chooser( $wp_customize,
        'workart_pro_theme_options[popular_products_content_product_' . $i . ']',
            array(
                'label'             => sprintf( esc_html__( 'Select Product %d', 'workart-pro' ), $i ),
                'section'           => 'workart_pro_popular_products_section',
                'choices'           => workart_pro_product_choices(),
                'active_callback'   => 'workart_pro_is_popular_products_section_content_product_enable',
            )
        )
    );

    // Workart_Pro_Customize_Horizontal_Line
	$wp_customize->add_setting('workart_pro_theme_options[popular_products_separator'. $i .']',
        array(
            'sanitize_callback'      => 'workart_pro_sanitize_html',
        )
    );

    $wp_customize->add_control(new Workart_Pro_Customize_Horizontal_Line($wp_customize,
        'workart_pro_theme_options[popular_products_separator'. $i .']',
            array(
                'type'                  => 'hr',
                'section'               => 'workart_pro_popular_products_section',
                'active_callback'       => 'workart_pro_is_popular_products_section_separator_enable'
            )
        )
    );

}

// // Add dropdown categories setting and control.
// $wp_customize->add_setting( 'workart_pro_theme_options[popular_products_category]',
//     array(
//         'sanitize_callback' => 'workart_pro_sanitize_category_list',
//     )
// );

// $wp_customize->add_control( new Workart_Pro_Dropdown_Multiple_Chooser( $wp_customize,
// 		'workart_pro_theme_options[popular_products_category]', 
// 		array(
// 			'label'             => esc_html__( 'Select Excluding Categories', 'workart-pro' ),
// 			'section'           => 'workart_pro_popular_products_section',
// 			'type'              => 'dropdown_multiple_chooser',
// 			'choices'           =>  workart_pro_category_choices(),
// 			'active_callback'   => 'workart_pro_is_popular_products_section_content_category_enable'
// 		)
// 	)
// );


// Add dropdown category setting and control.
$wp_customize->add_setting(  'workart_pro_theme_options[popular_products_content_product_category]',
	array(
		'sanitize_callback' => 'workart_pro_sanitize_product_category_list',
	)
);

$wp_customize->add_control( new Workart_Pro_Dropdown_Multiple_Chooser( $wp_customize,
	'workart_pro_theme_options[popular_products_content_product_category]',
		array(
			'label'             => esc_html__( 'Select Product Category', 'workart-pro' ),
			'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'workart-pro' ),
			'section'           => 'workart_pro_popular_products_section',
			'choices'           =>  workart_pro_product_category_choices(),
			'type'              => 'dropdown_multiple_chooser',
			'active_callback'	=> 'workart_pro_is_popular_products_section_content_product_category_enable'
		)
	)
);


// featured product btn title setting and control
$wp_customize->add_setting( 'workart_pro_theme_options[popular_products_btn_title]',
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'           => $options['popular_products_btn_title'],
		'transport'			=> 'postMessage',
	)
);

$wp_customize->add_control( 'workart_pro_theme_options[popular_products_btn_title]',
	array(
		'label'           	=> esc_html__( 'Button Label', 'workart-pro' ),
		'section'        	=> 'workart_pro_popular_products_section',
		'active_callback' 	=> 'workart_pro_is_popular_products_section_enable',
		'type'				=> 'text',
	)
);


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'workart_pro_theme_options[popular_products_btn_title]',
		array(
			'selector'            => '#workart_pro_popular_products_section li.product a.add_to_cart_button',
			'settings'            => 'workart_pro_theme_options[popular_products_btn_title]',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'workart_pro_popular_products_btn_title_partial',
		)
	);
}
