<?php
/**
 * Product Collection Section options
 *
 * @package Theme Palace
 * @subpackage Workart Pro
 * @since Workart Pro 1.0.0
 */
if ( !class_exists('WooCommerce') ) {
    return;
}
// Add Product section
$wp_customize->add_section( 'workart_pro_products_collection_section',
	array(
		'title'             => esc_html__( 'Product Collection','workart-pro' ),
		'description'       => esc_html__( 'Product Collection Section options.', 'workart-pro' ),
        'panel'             => 'workart_pro_front_page_panel',
		'active_callback'	=> function( $control ) {
			return (
				workart_pro_is_pro_layout( $control )
				||
				workart_pro_is_fourth_layout( $control )
			);
		},

	)
);

// Product content enable control and setting
$wp_customize->add_setting( 'workart_pro_theme_options[products_collection_section_enable]',
	array(
		'default'			=> 	$options['products_collection_section_enable'],
		'sanitize_callback' => 'workart_pro_sanitize_switch_control',
	)
);

$wp_customize->add_control( new Workart_Pro_Switch_Control( $wp_customize,
	'workart_pro_theme_options[products_collection_section_enable]',
		array(
			'label'             => esc_html__( 'Product Section Enable', 'workart-pro' ),
			'section'           => 'workart_pro_products_collection_section',
			'on_off_label' 		=> workart_pro_switch_options(),
		)
	)
);

// products_collection subtitle setting and control
$wp_customize->add_setting( 'workart_pro_theme_options[products_collection_subtitle]',
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> $options['products_collection_subtitle'],
		'transport'			=> 'postMessage',

	)
);

$wp_customize->add_control( 'workart_pro_theme_options[products_collection_subtitle]',
	array(
		'label'           	=> esc_html__( 'Section Sub Title', 'workart-pro' ),
		'section'        	=> 'workart_pro_products_collection_section',
		'active_callback' 	=> 'workart_pro_is_products_collection_section_enable',
		'type'				=> 'text',
	)
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'workart_pro_theme_options[products_collection_subtitle]',
		array(
			'selector'            => '#workart_pro_products_collection_section .section-header p.section-subtitle',
			'settings'            => 'workart_pro_theme_options[products_collection_subtitle]',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'workart_pro_products_collection_subtitle_partial',
		)
	);
}

// products_collection title setting and control
$wp_customize->add_setting( 'workart_pro_theme_options[products_collection_title]',
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> $options['products_collection_title'],
		'transport'			=> 'postMessage',

	)
);

$wp_customize->add_control( 'workart_pro_theme_options[products_collection_title]',
	array(
		'label'           	=> esc_html__( 'Section Title', 'workart-pro' ),
		'section'        	=> 'workart_pro_products_collection_section',
		'active_callback' 	=> 'workart_pro_is_products_collection_section_enable',
		'type'				=> 'text',
	)
);


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'workart_pro_theme_options[products_collection_title]',
		array(
			'selector'            => '#workart_pro_products_collection_section .section-header h2.section-title',
			'settings'            => 'workart_pro_theme_options[products_collection_title]',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'workart_pro_products_collection_title_partial',
		)
	);
}

// Product content type control and setting
$wp_customize->add_setting( 'workart_pro_theme_options[products_collection_content_type]',
	array(
		'default'          	=> $options['products_collection_content_type'],
		'sanitize_callback' => 'workart_pro_sanitize_select',
	)
);

$wp_customize->add_control( 'workart_pro_theme_options[products_collection_content_type]',
	array(
		'label'             => esc_html__( 'Content Type', 'workart-pro' ),
		'section'           => 'workart_pro_products_collection_section',
		'type'				=> 'select',
		'active_callback' 	=> 'workart_pro_is_products_collection_section_enable',
		'choices'			=>  workart_pro_products_collection_content_type()
	)
);

// Event social icons number control and setting
$wp_customize->add_setting( 'workart_pro_theme_options[products_collection_count]',
	array(
		'default'          	=> $options['products_collection_count'],
		'sanitize_callback' => 'workart_pro_sanitize_number_range',
		'validate_callback' => 'workart_pro_validate_products_collection_count',
	)
);

$wp_customize->add_control( 'workart_pro_theme_options[products_collection_count]',
	array(
		'label'             => esc_html__( 'Number of Product', 'workart-pro' ),
		'description'       => esc_html__( 'Note: Min 2 & Max 4. Please input the valid number and save. Then refresh the page to see the change.', 'workart-pro' ),
		'section'           => 'workart_pro_products_collection_section',
		'active_callback'   => 'workart_pro_is_products_collection_section_enable',
		'type'				=> 'number',
		'input_attrs'		=> array(
			'min'	=> 2,
			'max'	=> 4,
			'style' => 'width: 100px;'
		),
	)
);

for ( $i = 1; $i <= $options['products_collection_count']; $i++ ) :

	// products_collection pages drop down chooser control and setting
	$wp_customize->add_setting( 'workart_pro_theme_options[products_collection_content_page_' . $i . ']',
		array(
			'sanitize_callback' => 'workart_pro_sanitize_page',
		)
	);

	$wp_customize->add_control( new Workart_Pro_Dropdown_Chooser( $wp_customize,
		'workart_pro_theme_options[products_collection_content_page_' . $i . ']',
			array(
				'label'             => sprintf( esc_html__( 'Select Page %d', 'workart-pro' ), $i ),
				'section'           => 'workart_pro_products_collection_section',
				'choices'			=> workart_pro_page_choices(),
				'active_callback'	=> 'workart_pro_is_products_collection_section_content_page_enable',
			)
		)
	);

	// products_collection posts drop down chooser control and setting
	$wp_customize->add_setting( 'workart_pro_theme_options[products_collection_content_post_' . $i . ']',
		array(
			'sanitize_callback' => 'workart_pro_sanitize_page',
		)
	);
	
	$wp_customize->add_control( new Workart_Pro_Dropdown_Chooser( $wp_customize,
		'workart_pro_theme_options[products_collection_content_post_' . $i . ']',
			array(
				'label'             => sprintf( esc_html__( 'Select Post %d', 'workart-pro' ), $i ),
				'section'           => 'workart_pro_products_collection_section',
				'choices'			=> workart_pro_post_choices(),
				'active_callback'	=> 'workart_pro_is_products_collection_section_content_post_enable',
			)
		)
	);

	// products_collection posts drop down chooser control and setting
	$wp_customize->add_setting( 'workart_pro_theme_options[products_collection_content_product_' . $i . ']',
		array(
			'sanitize_callback' => 'workart_pro_sanitize_page',
		)
	);

	$wp_customize->add_control( new Workart_Pro_Dropdown_Chooser( $wp_customize,
		'workart_pro_theme_options[products_collection_content_product_' . $i . ']',
			array(
				'label'             => sprintf( esc_html__( 'Select Product %d', 'workart-pro' ), $i ),
				'section'           => 'workart_pro_products_collection_section',
				'choices'			=> workart_pro_product_choices(),
				'active_callback'	=> 'workart_pro_is_products_collection_section_content_product_enable',
			)
		)
	);

	// Workart_Pro_Customize_Horizontal_Line
	$wp_customize->add_setting('workart_pro_theme_options[products_collection_separator'. $i .']',
		array(
			'sanitize_callback'      => 'workart_pro_sanitize_html',
		)
	);

    $wp_customize->add_control(new Workart_Pro_Customize_Horizontal_Line($wp_customize,
		'workart_pro_theme_options[products_collection_separator'. $i .']',
			array(
				'type'                  => 'hr',
				'section'               => 'workart_pro_products_collection_section',
				'active_callback'       => 'workart_pro_is_products_collection_section_separator_enable'
			)
		)
	);
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'workart_pro_theme_options[products_collection_content_product_category]',
	array(
		'sanitize_callback' => 'absint',
	)
);

$wp_customize->add_control( new Workart_Pro_Dropdown_Taxonomies_Control( $wp_customize,
	'workart_pro_theme_options[products_collection_content_product_category]',
		array(
			'label'             => esc_html__( 'Select Product Category', 'workart-pro' ),
			'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'workart-pro' ),
			'section'           => 'workart_pro_products_collection_section',
			'taxonomy'			=> 'product_cat',
			'type'              => 'dropdown-taxonomies',
			'active_callback'	=> 'workart_pro_is_products_collection_section_content_product_category_enable'
		)
	)
);


// featured product btn title setting and control
$wp_customize->add_setting( 'workart_pro_theme_options[products_collection_btn_title]',
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'           => $options['products_collection_btn_title'],
		'transport'			=> 'postMessage',

	)
);

$wp_customize->add_control( 'workart_pro_theme_options[products_collection_btn_title]',
	array(
		'label'           	=> esc_html__( 'Button Label ', 'workart-pro' ),
		'section'        	=> 'workart_pro_products_collection_section',
		'active_callback' 	=> 'workart_pro_is_products_collection_section_enable',
		'type'				=> 'text',
	)
);


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'workart_pro_theme_options[products_collection_btn_title]',
		array(
			'selector'            => '#workart_pro_products_collection_section .section-content div.read-more a',
			'settings'            => 'workart_pro_theme_options[products_collection_btn_title]',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'workart_pro_products_collection_btn_title_partial',
		)
	);
}