<?php
/**
 * Recent Products Section options
 *
 * @package Theme Palace
 * @subpackage Workart Pro
 * @since Workart Pro 1.0.0
 */
if ( !class_exists('WooCommerce') ) {
    return;
}

// Add recent_product section
$wp_customize->add_section( 'workart_pro_recent_products_section',
    array(
        'title'             => esc_html__( 'Recent Product','workart-pro' ),
        'description'       => esc_html__( 'Note: To activate this section you need to install WooCommerce Plugin.', 'workart-pro' ),
        'panel'             => 'workart_pro_front_page_panel',
        'active_callback'	=> function( $control ) {
            return (
                workart_pro_is_pro_layout( $control )
                ||
                workart_pro_is_second_layout( $control )
                ||
                workart_pro_is_third_layout( $control )
                ||
                workart_pro_is_fourth_layout( $control )
            );
        },
    )
);

// recent_product content enable control and setting
$wp_customize->add_setting( 'workart_pro_theme_options[recent_products_section_enable]',
    array(
        'default'           =>  $options['recent_products_section_enable'],
        'sanitize_callback' => 'workart_pro_sanitize_switch_control',
    )
);

$wp_customize->add_control( new Workart_Pro_Switch_Control( $wp_customize,
    'workart_pro_theme_options[recent_products_section_enable]',
        array(
            'label'             => esc_html__( 'Recent product Section Enable', 'workart-pro' ),
            'section'           => 'workart_pro_recent_products_section',
            'on_off_label'      => workart_pro_switch_options(),
        )
    )
);

// recent_product sub title setting and control
$wp_customize->add_setting( 'workart_pro_theme_options[recent_products_sub_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['recent_products_sub_title'],
        'transport'         => 'postMessage',
    )
);

$wp_customize->add_control( 'workart_pro_theme_options[recent_products_sub_title]',
    array(
        'label'             => esc_html__( 'Section SubTitle', 'workart-pro' ),
        'section'           => 'workart_pro_recent_products_section',
        'active_callback'   => 'workart_pro_is_recent_products_section_enable',
        'type'              => 'text',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'workart_pro_theme_options[recent_products_sub_title]',
        array(
            'selector'            => '#workart_pro_recent_products_section div.section-header p.section-subtitle',
            'settings'            => 'workart_pro_theme_options[recent_products_sub_title]',
            'container_inclusive' => false,
            'fallback_refresh'    => true,
            'render_callback'     => 'workart_pro_recent_products_sub_title_partial',
        )
    );
}

// recent_product title setting and control
$wp_customize->add_setting( 'workart_pro_theme_options[recent_products_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['recent_products_title'],
        'transport'         => 'postMessage',
    )
);

$wp_customize->add_control( 'workart_pro_theme_options[recent_products_title]',
    array(
        'label'             => esc_html__( ' Section Title', 'workart-pro' ),
        'section'           => 'workart_pro_recent_products_section',
        'active_callback'   => 'workart_pro_is_recent_products_section_enable',
        'type'              => 'text',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'workart_pro_theme_options[recent_products_title]',
        array(
            'selector'            => '#workart_pro_recent_products_section div.section-header h2.section-title',
            'settings'            => 'workart_pro_theme_options[recent_products_title]',
            'container_inclusive' => false,
            'fallback_refresh'    => true,
            'render_callback'     => 'workart_pro_recent_products_title_partial',
        )
    );
}


$wp_customize->add_setting( 'workart_pro_theme_options[recent_products_count]',
    array(
        'default'           => $options['recent_products_count'],
        'sanitize_callback' => 'workart_pro_sanitize_number_range',
        'validate_callback' => 'workart_pro_validate_recent_products_count',
    )
);

$wp_customize->add_control( 'workart_pro_theme_options[recent_products_count]',
    array(
        'label'             => esc_html__( 'Number of Product', 'workart-pro' ),
        'description'       => esc_html__( 'Note: Min 1 & Max 8. Please input the valid number and save. Then refresh the page to see the change.', 'workart-pro' ),
        'section'           => 'workart_pro_recent_products_section',
        'active_callback'   => 'workart_pro_is_recent_products_section_enable',
        'type'              => 'number',
        'input_attrs'       => array(
            'min'   => 1,
            'max'   => 8,
            'style' => 'width: 100px;'
        ),
    )
);

$wp_customize->add_setting( 'workart_pro_theme_options[recent_products_content_type]',
    array(
        'default'           => $options['recent_products_content_type'],
        'sanitize_callback' => 'workart_pro_sanitize_select',
    )
);

$wp_customize->add_control( 'workart_pro_theme_options[recent_products_content_type]',
    array(
        'label'             => esc_html__( 'Content Type', 'workart-pro' ),
        'section'           => 'workart_pro_recent_products_section',
        'type'              => 'select',
        'active_callback'   => 'workart_pro_is_recent_products_section_enable',
        'choices'           => array(
            'product'           => esc_html__( 'Product', 'workart-pro' ),
            'product-category'  => esc_html__( 'Product Category', 'workart-pro' ),
        ),
    )
);

for( $i = 1 ; $i <= $options['recent_products_count'] ; $i++ ){

    $wp_customize->add_setting( 'workart_pro_theme_options[recent_products_content_product_' . $i . ']',
        array(
            'sanitize_callback' => 'workart_pro_sanitize_page',
        )
    );

    $wp_customize->add_control( new Workart_Pro_Dropdown_Chooser( $wp_customize,
        'workart_pro_theme_options[recent_products_content_product_' . $i . ']',
            array(
                'label'             => sprintf( esc_html__( 'Select Product %d', 'workart-pro' ), $i ),
                'section'           => 'workart_pro_recent_products_section',
                'choices'           => workart_pro_product_choices(),
                'active_callback'   => 'workart_pro_is_recent_products_section_content_product_enable',
            )
        )
    );

    // Workart_Pro_Customize_Horizontal_Line
	$wp_customize->add_setting('workart_pro_theme_options[recent_products_separator'. $i .']',
        array(
            'sanitize_callback'      => 'workart_pro_sanitize_html',
        )
    );

    $wp_customize->add_control(new Workart_Pro_Customize_Horizontal_Line($wp_customize,
        'workart_pro_theme_options[recent_products_separator'. $i .']',
            array(
                'type'                  => 'hr',
                'section'               => 'workart_pro_recent_products_section',
                'active_callback'       => 'workart_pro_is_recent_products_section_separator_enable'
            )
        )
    );

}

$wp_customize->add_setting(  'workart_pro_theme_options[recent_products_category]',
    array(
        'sanitize_callback' => 'absint',
    )
);

$wp_customize->add_control( new Workart_Pro_Dropdown_Taxonomies_Control( $wp_customize,
    'workart_pro_theme_options[recent_products_category]',
        array(
            'label'             => esc_html__( 'Select Product Categories', 'workart-pro' ),
            'description'       => esc_html__( 'Note: Press CTRL and select multiple category. Latest four posts will be shown from each selected category', 'workart-pro' ),
            'section'           => 'workart_pro_recent_products_section',
            'taxonomy'          => 'product_cat',
            'type'              => 'dropdown-taxonomies',
            'active_callback'   => 'workart_pro_is_recent_products_section_content_product_category_enable',
        )
    )
);

// Recent product Add to Cart content setting
$wp_customize->add_setting('workart_pro_theme_options[recent_products_add_to_cart_btn_label]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['recent_products_add_to_cart_btn_label']

    )
);

$wp_customize->add_control('workart_pro_theme_options[recent_products_add_to_cart_btn_label]',
    array(
        'section'			=> 'workart_pro_recent_products_section',
        'label'				=> esc_html__( 'Add To Cart Button Label', 'workart-pro' ),
        'type'          	=>'text',
        'active_callback'	=> 'workart_pro_is_recent_products_section_enable'
    )
);


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'workart_pro_theme_options[recent_products_add_to_cart_btn_label]',
        array(
            'selector'            => '#workart_pro_recent_products_section a.add_to_cart_button',
            'settings'            => 'workart_pro_theme_options[recent_products_add_to_cart_btn_label]',
            'fallback_refresh'    => true,
            'container_inclusive' => false,
            'render_callback'     => 'workart_pro_recent_products_add_to_cart_btn_label_partial',
        ) 
    );
}
