<?php

/**
 * Testimonial Section options
 *
 * @package Theme Palace
 * @subpackage  Workart Pro
 * @since  Workart Pro 1.0.0
 */

// Add Testimonial section
$wp_customize->add_section('workart_pro_testimonial_section',
    array(
        'title'         => esc_html__('Testimonials', 'workart-pro'),
        'description'   => esc_html__('Testimonials Section options.', 'workart-pro'),
        'panel'         => 'workart_pro_front_page_panel',
        'active_callback'	=> function( $control ) {
            return (
                workart_pro_is_pro_layout( $control )
                ||
                workart_pro_is_default_layout( $control )
                ||
                workart_pro_is_second_layout( $control )
            );
        },

    )
);

// Testimonial content enable control and setting
$wp_customize->add_setting('workart_pro_theme_options[testimonial_section_enable]',
    array(
        'default'           => $options['testimonial_section_enable'],
        'sanitize_callback' => 'workart_pro_sanitize_switch_control',
    )
);

$wp_customize->add_control(new  Workart_Pro_Switch_Control($wp_customize,
    'workart_pro_theme_options[testimonial_section_enable]',
        array(
            'label'         => esc_html__('Testimonial Section Enable', 'workart-pro'),
            'section'       => 'workart_pro_testimonial_section',
            'on_off_label'  => workart_pro_switch_options(),
        )
    )
);

// Slider autoplay enable control and setting
$wp_customize->add_setting( 'workart_pro_theme_options[testimonial_autoplay_enable]',
	array(
		'default'			=> 	$options['testimonial_autoplay_enable'],
		'sanitize_callback' => 'workart_pro_sanitize_switch_control',
	)
);

$wp_customize->add_control( new  Workart_Pro_Switch_Control( $wp_customize,
	'workart_pro_theme_options[testimonial_autoplay_enable]',
		array(
			'label'             => esc_html__( 'Autoplay Testimonial Enable', 'workart-pro' ),
			'section'           => 'workart_pro_testimonial_section',
			'active_callback'   => 'workart_pro_is_testimonial_section_enable',
			'on_off_label' 		=> workart_pro_switch_options(),
		)
	)
);
// Testimonial section title control and setting
$wp_customize->add_setting('workart_pro_theme_options[testimonial_sub_title]',
    array(
        'default'               => $options['testimonial_sub_title'],
        'sanitize_callback'     => 'sanitize_text_field',
        'transport'             => 'postMessage'
    )
);

$wp_customize->add_control('workart_pro_theme_options[testimonial_sub_title]',
    array(
        'label'                 => esc_html__('Section Sub Title', 'workart-pro'),
        'section'               => 'workart_pro_testimonial_section',
        'type'                  => 'text',
        'active_callback'       => 'workart_pro_is_testimonial_section_enable',
    )
);

$wp_customize->selective_refresh->add_partial('workart_pro_theme_options[testimonial_sub_title]',
    array(
        'selector'          => '#workart_pro_testimonial_section div.section-header > p',
        'render_callback'   => 'workart_pro_testimonial_sub_title_partial',
    )
);


// Testimonial Excerpt length setting and control.
$wp_customize->add_setting( 'workart_pro_theme_options[testimonial_excerpt_length]',
	array(
		'sanitize_callback' => 'workart_pro_sanitize_number_range',
		'default'			=> $options['testimonial_excerpt_length'],
	)
);

$wp_customize->add_control( 'workart_pro_theme_options[testimonial_excerpt_length]',
	array(
		'label'       		=> esc_html__( 'Excerpt Length', 'workart-pro' ),
		'description' 		=> esc_html__( 'Total words to be displayed in Testimonial section', 'workart-pro' ),
		'section'     		=> 'workart_pro_testimonial_section',
		'type'        		=> 'number',
		'active_callback' 	=> 'workart_pro_is_testimonial_section_enable',
	)
);

//Testimonial section content control type setting and control
$wp_customize->add_setting('workart_pro_theme_options[testimonial_content_type]',
    array(
        'default'               => $options['testimonial_content_type'],
        'sanitize_callback'     => 'workart_pro_sanitize_select',
    )
);

$wp_customize->add_control('workart_pro_theme_options[testimonial_content_type]',
    array(
        'label'                 => esc_html__('Content Type', 'workart-pro'),
        'section'               => 'workart_pro_testimonial_section',
        'type'                  => 'select',
        'active_callback'       => 'workart_pro_is_testimonial_section_enable',
        'choices'               => array(
            'page'      => esc_html__('Page', 'workart-pro'),
            'post'      => esc_html__('Post', 'workart-pro'),
            'category'  => esc_html__('Category', 'workart-pro'),
        ),
    )
);


// Testimonial post number control and setting
$wp_customize->add_setting('workart_pro_theme_options[testimonial_posts_count]',
    array(
        'default'               => $options['testimonial_posts_count'],
        'sanitize_callback'     => 'workart_pro_sanitize_number_range',
		'validate_callback'     => 'workart_pro_validate_testimonial_count',
    )
);

$wp_customize->add_control('workart_pro_theme_options[testimonial_posts_count]',
    array(
        'label'                 => esc_html__('Number of Posts', 'workart-pro'),
		'description'           => esc_html__( 'Note: Min 3 & Max 9. Please input the valid number and save. Then refresh the page to see the change.', 'workart-pro' ),
        'section'               => 'workart_pro_testimonial_section',
        'active_callback'       => 'workart_pro_is_testimonial_section_enable',
        'type'                  => 'number',
        'input_attrs'		=> array(
			'min'	=> 3,
			'max'	=> 9,
			'style' => 'width: 100px;'
		),
    )
);

for ($i = 1; $i <= $options['testimonial_posts_count']; $i++):

    // Testimonial pages drop down chooser control and setting
    $wp_customize->add_setting('workart_pro_theme_options[testimonial_content_page_' . $i . ']',
        array(
            'sanitize_callback' => 'workart_pro_sanitize_page',
        )
    );

    $wp_customize->add_control(new  Workart_Pro_Dropdown_Chooser($wp_customize,
        'workart_pro_theme_options[testimonial_content_page_' . $i . ']',
            array(
                'label'             => sprintf(esc_html__('Select Page : %d', 'workart-pro'), $i),
                'section'           => 'workart_pro_testimonial_section',
                'choices'           => workart_pro_page_choices(),
                'active_callback'   => 'workart_pro_is_testimonial_section_content_page_enable',
            )
        )
    );

    // Testimonial posts drop down chooser control and setting
    $wp_customize->add_setting('workart_pro_theme_options[testimonial_content_post_' . $i . ']',
        array(
            'sanitize_callback' => 'workart_pro_sanitize_page',
        )
    );

    $wp_customize->add_control(new  Workart_Pro_Dropdown_Chooser($wp_customize,
        'workart_pro_theme_options[testimonial_content_post_' . $i . ']',
            array(
                'label'             => sprintf(esc_html__('Select Post : %d', 'workart-pro'), $i),
                'section'           => 'workart_pro_testimonial_section',
                'choices'           => workart_pro_post_choices(),
                'active_callback'   => 'workart_pro_is_testimonial_section_content_post_enable',
            )
        )
    );

    // Testimonial posts sub title control and setting
    $wp_customize->add_setting('workart_pro_theme_options[testimonial_post_designation_' . $i . ']',
        array(
            'sanitize_callback' => 'sanitize_text_field',
        )
    );

    $wp_customize->add_control(new  Workart_Pro_Dropdown_Chooser($wp_customize,
        'workart_pro_theme_options[testimonial_post_designation_' . $i . ']',
            array(
                'label'             => sprintf(esc_html__('Select Designation : %d', 'workart-pro'), $i),
                'section'           => 'workart_pro_testimonial_section',
                'active_callback'   => 'workart_pro_is_testimonial_section_enable',
                'type'              => 'text',
            )
        )
    );

    //testimonial separator
    $wp_customize->add_setting('workart_pro_theme_options[testimonial_separator'. $i .']',
        array(
            'sanitize_callback'      => 'workart_pro_sanitize_html',
        )
    );

    $wp_customize->add_control(new  Workart_Pro_Customize_Horizontal_Line($wp_customize,
        'workart_pro_theme_options[testimonial_separator'. $i .']',
            array(
                'active_callback'       => 'workart_pro_is_testimonial_section_enable',
                'type'                  =>'hr',
                'section'               =>'workart_pro_testimonial_section',
            )
        )
    );

endfor;

// Testimonial category drop down chooser control and setting
$wp_customize->add_setting('workart_pro_theme_options[testimonial_category]',
    array(
        'sanitize_callback' => 'workart_pro_sanitize_single_category',
    )
);

$wp_customize->add_control(new  Workart_Pro_Dropdown_Taxonomies_Control($wp_customize,
    'workart_pro_theme_options[testimonial_category]',
            array(
                'label'             => esc_html__('Select Categories', 'workart-pro'),
                'description'       => esc_html__('Note: Latest selected no of posts will be shown from selected category', 'workart-pro'),
                'type'              => 'dropdown-taxonomies',
                'section'           => 'workart_pro_testimonial_section',
                'active_callback'   => 'workart_pro_is_testimonial_section_content_category_enable',
            )
        )
    );

