<?php
/**
 * trending_products Section options
 *
 * @package Theme Palace
 * @subpackage Workart Pro
 * @since Workart Pro 1.0.0
 */
if ( !class_exists('WooCommerce') ) {
	return;
}
// Add trending_products section
$wp_customize->add_section( 'workart_pro_trending_products_section',
	array(
		'title'             => esc_html__( 'Trending Product','workart-pro' ),
		'description'       => esc_html__( 'Trending Product Section options.', 'workart-pro' ),
		'panel'             => 'workart_pro_front_page_panel',
		'active_callback'	=> function( $control ) {
			return (
				workart_pro_is_pro_layout( $control )
				||
				workart_pro_is_fourth_layout( $control )
			);
		},
	)
);

// trending_products content enable control and setting
$wp_customize->add_setting( 'workart_pro_theme_options[trending_products_section_enable]',
	array(
		'default'			=> 	$options['trending_products_section_enable'],
		'sanitize_callback' => 'workart_pro_sanitize_switch_control',
	)
);

$wp_customize->add_control( new Workart_Pro_Switch_Control( $wp_customize,
	'workart_pro_theme_options[trending_products_section_enable]',
		array(
			'label'             => esc_html__( 'Trending Product Section Enable', 'workart-pro' ),
			'section'           => 'workart_pro_trending_products_section',
			'on_off_label' 		=> workart_pro_switch_options(),
		)
	)
);

$wp_customize->add_setting( 'workart_pro_theme_options[trending_products_count]',
	array(
		'default'          	=> $options['trending_products_count'],
		'sanitize_callback' => 'workart_pro_sanitize_number_range',
		'validate_callback' => 'workart_pro_validate_trending_products_count',
	)
);

$wp_customize->add_control( 'workart_pro_theme_options[trending_products_count]',
	array(
		'label'             => esc_html__( 'Number of Product Per Column', 'workart-pro' ),
		'description'       => esc_html__( 'Note: Min 1 & Max 8. Please input the valid number and save. Then refresh the page to see the change.', 'workart-pro' ),
		'section'           => 'workart_pro_trending_products_section',
		'active_callback'   => 'workart_pro_is_trending_products_section_enable',
		'type'				=> 'number',
		'input_attrs'		=> array(
			'min'	=> 1,
			'max'	=> 8,
			'style' => 'width: 100px;'
		),
	)
);


for( $i = 1 ; $i <= 3 ; $i++ ){

	$wp_customize->add_setting( 'workart_pro_theme_options[trending_products_hr_'. $i .']',
		array(
			'sanitize_callback' => 'sanitize_text_field'
		)
	);

	$wp_customize->add_control( new Workart_Pro_Customize_Horizontal_Line( $wp_customize,
		'workart_pro_theme_options[trending_products_hr_'. $i .']',
			array(
				'section'         => 'workart_pro_trending_products_section',
				'active_callback' => 'workart_pro_is_trending_products_section_enable',
				'type'			  => 'hr'
			)
		)
	);


	$wp_customize->add_setting( 'workart_pro_theme_options[trending_products_column_'. $i .']',
		array(
			'sanitize_callback' => 'sanitize_text_field'
		)
	);

		$wp_customize->add_control( new Workart_Pro_Customize_Column( $wp_customize,
		'workart_pro_theme_options[trending_products_column_'. $i .']',
			array(
				'label'			  => esc_html__('Column ', 'workart-pro').$i,
				'section'         => 'workart_pro_trending_products_section',
				'active_callback' => 'workart_pro_is_trending_products_section_enable',
				'type'			  => 'column'
			)
		)
	);

	// trending_products title setting and control
	$wp_customize->add_setting( 'workart_pro_theme_options[trending_products_title_'.$i.']',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'default'           => $options['trending_products_title'],
		)
	);

	$wp_customize->add_control( 'workart_pro_theme_options[trending_products_title_'.$i.']',
		array(
			'label'             => esc_html__( 'Title', 'workart-pro' ),
			'section'           => 'workart_pro_trending_products_section',
			'active_callback'   => 'workart_pro_is_trending_products_section_enable',
			'type'              => 'text',
			'transport'			=> 'postMessage'
		)
	);

	// Abort if selective refresh is not available.
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'workart_pro_theme_options[trending_products_title_'.$i.']',
			array(
				'selector'            => '#workart_pro_trending_products_section div.product-wrapper h2.'.$i.'',
				'settings'            => 'workart_pro_theme_options[trending_products_title_'.$i.']',
				'fallback_refresh'    => true,
				'container_inclusive' => false,
				'render_callback'     => workart_pro_trending_products_title_partial($i),
			) 
		);
	}


	$wp_customize->add_setting( 'workart_pro_theme_options[trending_products_content_type_'.$i.']',
		array(
			'default'          	=> 'product',
			'sanitize_callback' => 'workart_pro_sanitize_select',
		)
	);

	$wp_customize->add_control( 'workart_pro_theme_options[trending_products_content_type_'.$i.']',
		array(
			'label'             => esc_html__( 'Content Type', 'workart-pro' ),
			'section'           => 'workart_pro_trending_products_section',
			'type'				=> 'select',
			'active_callback' 	=> 'workart_pro_is_trending_products_section_enable',
			'choices'			=> array(
				'product'  			 => esc_html__( 'Product', 'workart-pro' ),
				'product-category'   => esc_html__( 'Product Category', 'workart-pro' ),
			),
		)
	);

	for ( $j=1 ; $j <= $options['trending_products_count']; $j++ ) { 

		$wp_customize->add_setting( 'workart_pro_theme_options[trending_products_content_product_'. $i.$j. ']',
			array(
				'sanitize_callback' => 'workart_pro_sanitize_page',
			)
		);

		$wp_customize->add_control( new Workart_Pro_Dropdown_Chooser( $wp_customize,
			'workart_pro_theme_options[trending_products_content_product_' .$i.$j. ']', 
				array(
					'label'             => sprintf( esc_html__( 'Select Product %d', 'workart-pro' ), $j ),
					'section'           => 'workart_pro_trending_products_section',
					'choices'			=> workart_pro_product_choices(),
					'active_callback'	=> 'workart_pro_is_trending_products_section_content_product_enable_'.$i,
				)
			)
		);
	}

	$wp_customize->add_setting(  'workart_pro_theme_options[trending_products_content_product_category_'.$i.']',
		array(
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control( new Workart_Pro_Dropdown_Taxonomies_Control( $wp_customize,
		'workart_pro_theme_options[trending_products_content_product_category_'.$i.']',
			array(
				'label'             => esc_html__( 'Select Product Categories', 'workart-pro' ),
				'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'workart-pro' ),
				'section'           => 'workart_pro_trending_products_section',
				'taxonomy'			=> 'product_cat',
				'type'              => 'dropdown-taxonomies',
				'active_callback'	=> 'workart_pro_is_trending_products_section_content_product_category_enable_'.$i,

			)
		)
	);
}