<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage  Workart Pro
 * @since  Workart Pro 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function workart_pro_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'workart-pro' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function workart_pro_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'workart-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    wp_reset_postdata();
    return  $choices;
}

/**
 * List of products for post choices.
 * @return Array Array of post ids and name.
 */
function workart_pro_product_choices() {
    $posts = get_posts( array( 'numberposts' => -1, 'post_type' => 'product' ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'workart-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of category for category choices.
 * @return Array Array of post ids and name.
 */
function workart_pro_category_choices() {
    $tax_args = array(
        'hierarchical' => 0,
        'taxonomy'     => 'category',
    );
    $taxonomies = get_categories( $tax_args );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'workart-pro' );
    foreach ( $taxonomies as $tax ) {
        $choices[ $tax->term_id ] = $tax->name;
    }
    return  $choices;
}

/**
 * List of category for category choices.
 * @return Array Array of post ids and name.
 */
function workart_pro_product_category_choices() {
    $tax_args = array(
        'hierarchical' => 0,
        'taxonomy'     => 'product_cat',
    );
    $taxonomies = get_categories( $tax_args );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'workart-pro' );
    foreach ( $taxonomies as $tax ) {
        $choices[ $tax->term_id ] = $tax->name;
    }
    return  $choices;
}

if ( ! function_exists( 'workart_pro_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function workart_pro_site_layout() {
        $workart_pro_site_layout = array(
            'wide'          => esc_url( get_template_directory_uri() . '/assets/images/full.png' ),
            'boxed-layout'  => esc_url( get_template_directory_uri() . '/assets/images/boxed.png' ),
            'frame-layout'  => esc_url( get_template_directory_uri() . '/assets/images/framed.png' ),
        );

        $output = apply_filters( 'workart_pro_site_layout', $workart_pro_site_layout );
        return $output;
    }
endif;

if ( ! function_exists( 'workart_pro_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function workart_pro_selected_sidebar() {
        $workart_pro_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'workart-pro' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'workart-pro' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'workart-pro' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'workart-pro' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'workart-pro' ),
        );

        $output = apply_filters( 'workart_pro_selected_sidebar', $workart_pro_selected_sidebar );

        return $output;
    }
endif;


if ( ! function_exists( 'workart_pro_global_sidebar_position' ) ) :
    /**
     * Global Sidebar position
     * @return array Global Sidebar positions
     */
    function workart_pro_global_sidebar_position() {
        $workart_pro_global_sidebar_position = array(
            'right-sidebar' => esc_url( get_template_directory_uri() . '/assets/images/right.png' ),
            'left-sidebar'  => esc_url( get_template_directory_uri() . '/assets/images/left.png' ),
            'no-sidebar'    => esc_url( get_template_directory_uri() . '/assets/images/full.png' ),
        );

        $output = apply_filters( 'workart_pro_global_sidebar_position', $workart_pro_global_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'workart_pro_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function workart_pro_sidebar_position() {
        $workart_pro_sidebar_position = array(
            'right-sidebar'         => esc_url( get_template_directory_uri() . '/assets/images/right.png' ),
            'left-sidebar'          => esc_url( get_template_directory_uri() . '/assets/images/left.png' ),
            'no-sidebar'            => esc_url( get_template_directory_uri() . '/assets/images/full.png' ),
            'no-sidebar-content'    => esc_url( get_template_directory_uri() . '/assets/images/boxed.png' ),
        );

        $output = apply_filters( 'workart_pro_sidebar_position', $workart_pro_sidebar_position );

        return $output;
    }
endif;

if ( ! function_exists( 'workart_pro_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function workart_pro_pagination_options() {
        $workart_pro_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'workart-pro' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'workart-pro' ),
            'infinite'  => esc_html__( 'Infinite', 'workart-pro' ),
        );

        $output = apply_filters( 'workart_pro_pagination_options', $workart_pro_pagination_options );

        return $output;
    }
endif;

if ( ! function_exists( 'workart_pro_get_spinner_list' ) ) :
    /**
     * List of spinner icons options.
     * @return array List of all spinner icon options.
     */
    function workart_pro_get_spinner_list() {
        $arr = array(
            'default'               => esc_html__( 'Default', 'workart-pro' ),
            'spinner-wheel'         => esc_html__( 'Wheel', 'workart-pro' ),
            'spinner-double-circle' => esc_html__( 'Double Circle', 'workart-pro' ),
            'spinner-two-way'       => esc_html__( 'Two Way', 'workart-pro' ),
            'spinner-umbrella'      => esc_html__( 'Umbrella', 'workart-pro' ),
            'spinner-dots'          => esc_html__( 'Dots', 'workart-pro' ),
            'spinner-one-way'       => esc_html__( 'One Way', 'workart-pro' ),
            'spinner-fidget'        => esc_html__( 'Fidget', 'workart-pro' ),
        );
        return apply_filters( 'workart_pro_spinner_list', $arr );
    }
endif;

if ( ! function_exists( 'workart_pro_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function workart_pro_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'workart-pro' ),
            'off'       => esc_html__( 'Disable', 'workart-pro' )
        );
        return apply_filters( 'workart_pro_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'workart_pro_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function workart_pro_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'workart-pro' ),
            'off'       => esc_html__( 'No', 'workart-pro' )
        );
        return apply_filters( 'workart_pro_hide_options', $arr );
    }
endif;

if ( ! function_exists( 'workart_pro_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function workart_pro_sortable_sections() {
        $options = workart_pro_get_theme_options();
  
        $sections = array(
            'hero_slider'               => esc_html__( 'Hero Slider', 'workart-pro' ),
            'featured_slider'           => esc_html__( 'Featured Slider', 'workart-pro' ),
            'our_services'              => esc_html__( 'Our Service', 'workart-pro' ),
            'featured_posts'            => esc_html__( 'Featured Post', 'workart-pro' ),
            'popular_posts'             => esc_html__( 'Popular Post', 'workart-pro' ),
            'about_us'                  => esc_html__( 'About us', 'workart-pro' ),
            'recent_posts'              => esc_html__( 'Recent Posts', 'workart-pro' ),
            'latest_posts'              => esc_html__( 'Latest Post', 'workart-pro' ),
            'gallery'                   => esc_html__( 'Gallery', 'workart-pro' ),
            'featured_artist'           => esc_html__( 'Featured Artist', 'workart-pro' ),
            'products_collection'        => esc_html__( 'Product Collection', 'workart-pro' ),
            'trending_products'         => esc_html__( 'Product Collection', 'workart-pro' ),
            'call_to_action'            => esc_html__( 'Call To Action', 'workart-pro' ),
            'featured_products'         => esc_html__( 'Featured Products', 'workart-pro' ),
            'popular_products'          => esc_html__( 'Popular Products', 'workart-pro' ),
            'latest_products'           => esc_html__( 'Latest Products', 'workart-pro' ),
            'recent_products'           => esc_html__( 'Recent Products', 'workart-pro' ),
            'subscribe'                 => esc_html__( 'Subscription', 'workart-pro' ),
            'testimonial'               => esc_html__( 'Testimonial', 'workart-pro' ),
            'our_partners'              => esc_html__( 'Our Partners', 'workart-pro' ),
        );
      
         
        return apply_filters( 'workart_pro_sortable_sections', $sections );
    }
endif;


if ( ! function_exists( 'workart_pro_hero_slider_content_type' ) ) :
    /**
     * Product Options
     * @return array site product options
     */
    function workart_pro_hero_slider_content_type() {
        $workart_pro_hero_slider_content_type = array(
            'page' 		=> esc_html__( 'Page', 'workart-pro' ),
			'post' 		=> esc_html__( 'Post', 'workart-pro' ),
			'category' 	=> esc_html__( 'Category', 'workart-pro' ),
        );

        if(class_exists('WooCommerce')){
            $workart_pro_hero_slider_content_type = array_merge($workart_pro_hero_slider_content_type, 
                array(
                    'product'            => esc_html__( 'Product', 'workart-pro' ),
                    'product-category'   => esc_html__( 'Product Category', 'workart-pro' ),
                )
            );
        }

        $output = apply_filters( 'workart_pro_hero_slider_content_type', $workart_pro_hero_slider_content_type );

        return $output;
    }
endif;

if ( ! function_exists( 'workart_pro_featured_products_content_type' ) ) :
    /**
     * Product Options
     * @return array site product options
     */
    function workart_pro_featured_products_content_type() {
        $workart_pro_featured_products_content_type = array(
			'post' 		=> esc_html__( 'Post', 'workart-pro' ),
        );

        if(class_exists('WooCommerce')){
            $workart_pro_featured_products_content_type = array_merge($workart_pro_featured_products_content_type, 
                array(
                    'product'            => esc_html__( 'Product', 'workart-pro' ),
                    'product-category'   => esc_html__( 'Product Category', 'workart-pro' ),
                )
            );
        }

        $output = apply_filters( 'workart_pro_featured_products_content_type', $workart_pro_featured_products_content_type );

        return $output;
    }
endif;

if ( ! function_exists( 'workart_pro_products_collection_content_type' ) ) :
    /**
     * Product Options
     * @return array site product options
     */
    function workart_pro_products_collection_content_type() {
        $workart_pro_products_collection_content_type = array(
			'post' 		=> esc_html__( 'Post', 'workart-pro' ),
			'page' 		=> esc_html__( 'Page', 'workart-pro' ),
        );

        if(class_exists('WooCommerce')){
            $workart_pro_products_collection_content_type = array_merge($workart_pro_products_collection_content_type, 
                array(
                    'product'            => esc_html__( 'Product', 'workart-pro' ),
                    'product-category'   => esc_html__( 'Product Category', 'workart-pro' ),
                )
            );
        }

        $output = apply_filters( 'workart_pro_products_collection_content_type', $workart_pro_products_collection_content_type );

        return $output;
    }
endif;

if ( ! function_exists( 'workart_pro_typography_options' ) ) :
    function workart_pro_typography_options(){
    $font_family_arr = array();
    $font_family_arr[''] = esc_html__( '--Default--', 'workart-pro' );

    // Make the request
    $request = wp_remote_get( get_theme_file_uri( 'assets/webfonts.json' ) );

    if( is_wp_error( $request ) ) {
        return false; // Bail early
    }
     // Retrieve the data
    $body = wp_remote_retrieve_body( $request );
    $data = json_decode( $body );
    if ( ! empty( $data ) ) {
        foreach ( $data->items as $items => $fonts ) {
            $family_str_arr = explode( ' ', $fonts->family );
            $family_value = implode( '+', $family_str_arr );
            $font_family_arr[ $family_value ] = $fonts->family;
        }
    }

    return $font_family_arr;
}
endif;