<?php
/**
 * Call To Action section
 *
 * This is the template for the content of Call To Action section
 *
 * @package Theme Palace
 * @subpackage  Workart Pro
 * @since  Workart Pro 1.0.0
 */
if ( ! function_exists( 'workart_pro_add_call_to_action_section' ) ) :
    /**
    * Add Call To Action section
    *
    *@since  Workart Pro 1.0.0
    */
    function workart_pro_add_call_to_action_section() {
        $options = workart_pro_get_theme_options();
        
        // Check if Call To Action is enabled on frontpage
        $call_to_action_enable = apply_filters( 'workart_pro_section_status', true, 'call_to_action_section_enable' );

        if ( true !== $call_to_action_enable ) {
            return false;
        }

        // Get Call To Action section details
        $section_details = array();
        $section_details = apply_filters( 'workart_pro_filter_call_to_action_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }

        // Render Call To Action section now.
        workart_pro_render_call_to_action_section( $section_details[0] );
    }
endif;

if ( ! function_exists( 'workart_pro_get_call_to_action_section_details' ) ) :
    /**
    * Call To Action section details.
    *
    * @since  Workart Pro 1.0.0
    * @param array $input Call To Action section details.
    */
    function workart_pro_get_call_to_action_section_details( $input ) {
        $options = workart_pro_get_theme_options();

        $call_to_action_content_type  = $options['call_to_action_content_type']; // Call To Action content type
        
        $content = array();
        switch ( $call_to_action_content_type ) {
        	
            case 'page':
                $page_id = ! empty( $options['call_to_action_content_page'] ) ? $options['call_to_action_content_page'] : '';
                $args = array(
                    'post_type'             => 'page',
                    'posts_per_page'        => 1,
                    'p'                     => $page_id,
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'post':
                $page_id = ! empty( $options['call_to_action_content_post'] ) ? $options['call_to_action_content_post'] : '';

                $args = array(
                    'post_type'             => 'post',
                    'p'                     => $page_id,
                    'posts_per_page'        => 1,
                    'ignore_sticky_posts'   => true,
                    );                    
            break;
            case 'custom':
                $page_post['excerpt']   = isset($options['call_to_action_custom_content']) ? $options['call_to_action_custom_content'] : '';
                $page_post['title']     = isset($options['call_to_action_custom_title'])? $options['call_to_action_custom_title']: '';
                $page_post['url']       = isset($options['call_to_action_us_btn_url']) ? $options['call_to_action_us_btn_url']: '#';
                $page_post['image']     = !empty($options['call_to_action_custom_image']) ? $options['call_to_action_custom_image']: get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';
                array_push( $content, $page_post );
                return $content;

            default:
            break;
        }
        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = workart_pro_trim_content( absint($options['call_to_action_excerpt_length']) );
                $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'medium_large' ) : get_template_directory_uri().'/assets/uploads/no-featured-image-600x450.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;

// Call To Action section content details.
add_filter( 'workart_pro_filter_call_to_action_section_details', 'workart_pro_get_call_to_action_section_details' );


if ( ! function_exists( 'workart_pro_render_call_to_action_section' ) ) :
  /**
   * Start Call To Action section
   *
   * @return string Call To Action content
   * @since  Workart Pro 1.0.0
   *
   */
   function workart_pro_render_call_to_action_section( $content_details = array() ) {
        $options    = workart_pro_get_theme_options();
        $btn_label  = $options['call_to_action_read_more'];

        if ( empty( $content_details ) ) {
            return;
        } ?>

            <div id="workart_pro_call_to_action_section" class="relative page-section">
                <div class="wrapper">
                    <article>
                        <div class="featured-image" style="background-image: url('<?php echo esc_url( $content_details['image'] ); ?>');">
                            <a href="<?php echo esc_url( $content_details['url'] ); ?>" class="post-thumbnail-link" title="<?php echo esc_attr( $content_details['title'] ); ?>"></a>
                        </div><!-- .featured-image -->

                        <div class="section-container">
                            <div class="section-header">
                                <p class="section-subtitle"><?php echo $options['call_to_action_sub_title']; ?></p>
                                <h2 class="section-title"><?php echo esc_html($content_details['title']); ?></h2>
                            </div><!-- .section-header -->

                            <div class="section-content">
                                <p><?php echo wp_kses_post($content_details['excerpt']); ?></p>
                            </div><!-- .section-content -->

                        <?php if( !empty($btn_label) && !empty( $content_details['url'] )) : ?>

                            <div class="read-more">
                                <a href="<?php echo esc_url( $content_details['url'] ); ?>" class="btn"><?php echo esc_html($btn_label); ?></a>
                            </div><!-- .read-more -->

                        <?php endif; ?>

                        </div><!-- .section-container -->
                    </article>
                </div><!-- .wrapper -->
            </div><!-- #workart_pro_call_to_action_section -->
    <?php }
endif;