<?php
/**
 * featured_products section
 *
 * This is the template for the content of featured_products section
 *
 * @package Theme Palace
 * @subpackage Workart Pro
 * @since Workart Pro 1.0.0
 */
if ( ! function_exists( 'workart_pro_add_featured_products_section' ) ) :
    /**
    * Add featured_products section
    *
    *@since Workart Pro 1.0.0
    */
    function workart_pro_add_featured_products_section() {
        $options = workart_pro_get_theme_options();
        // Check if featured_products is enabled on frontpage
        $featured_products_enable = apply_filters( 'workart_pro_section_status', true, 'featured_products_section_enable' );

        if ( ( true !== $featured_products_enable ) || ! class_exists( 'WooCommerce' ) ) {
            return false;
        }

        // Get featured_products section details
        $section_details = array();
        $section_details = apply_filters( 'workart_pro_filter_featured_products_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render featured_products section now.
        workart_pro_render_featured_products_section( $section_details );
    }
endif;

if ( ! function_exists( 'workart_pro_get_featured_products_section_details' ) ) :
    /**
    * featured_products section details.
    *
    * @since Workart Pro 1.0.0
    * @param array $input featured_products section details.
    */
    function workart_pro_get_featured_products_section_details( $input ) {
        $options = workart_pro_get_theme_options();

        // Content type.
        $featured_products_content_type  = $options['featured_products_content_type'];     
        $featured_products_count = ! empty( $options['featured_products_count'] ) ? $options['featured_products_count'] : 2;
        
        $content = array();
        switch ( $featured_products_content_type ) {

            case 'product':
                $page_ids = array();

                for ( $i = 1; $i <= $featured_products_count; $i++ ) {
                    if ( ! empty( $options['featured_products_content_product_' . $i] ) )
                        $page_ids[] = $options['featured_products_content_product_' . $i];
                }

                $args = array(
                    'post_type'         => 'product',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $featured_products_count ),
                    'orderby'           => 'post__in',
                );

            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $featured_products_count; $i++ ) {
                    if ( ! empty( $options['featured_products_content_post_' . $i] ) )
                        $post_ids[] = $options['featured_products_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'             => 'post',
                    'post__in'              => ( array ) $post_ids,
                    'posts_per_page'        => absint( $featured_products_count ),
                    'orderby'               => 'post__in',
                    'ignore_sticky_posts'   => true,
                );                    
            break;

            case 'product-category':
                $cat_id = ! empty( $options['featured_products_category'] ) ? $options['featured_products_category'] : '';

                $args = array(
                    'post_type'         => 'product',
                    'posts_per_page'    => absint( $featured_products_count ),
                    'tax_query'         => array(
                        array(
                            'taxonomy'  => 'product_cat',
                            'field'     => 'id',
                            'terms'     => $cat_id
                        )
                    )
                );

            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = workart_pro_trim_content( 10 );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'medium_large' ) : get_template_directory_uri().'/assets/uploads/no-featured-image-600x450.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// featured_products section content details.
add_filter( 'workart_pro_filter_featured_products_section_details', 'workart_pro_get_featured_products_section_details' );


if ( ! function_exists( 'workart_pro_render_featured_products_section' ) ) :
  /**
   * Start featured_products section
   *
   * @return string featured_products content
   * @since Workart Pro 1.0.0
   *
   */
   function workart_pro_render_featured_products_section( $content_details = array() ) {
        $options = workart_pro_get_theme_options();
        $featured_products_content_type  = $options['featured_products_content_type'];     

        if ( empty( $content_details ) ) {
            return;
        } ?>
            <div id="workart_pro_featured_products_section" class="relative page-section same-background">
                <div class="wrapper">
                    <div class="section-content clear col-2">
                    <?php foreach ( $content_details as $content ): ?>

                        <article>
                            <div class="featured-image" style="background-image: url('<?php echo esc_url($content['image']); ?>');">
                                <div class="entry-container">
                                    <span class="cat-links">
                                        <?php echo ($featured_products_content_type == 'post') ? the_category('', '', $content['id']) :  wc_get_product_category_list($content['id']); ?>
                                    </span><!-- .cat-links -->

                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>

                                    <div class="entry-content">
                                        <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                                    </div><!-- .entry-content -->

                                    <?php if(!empty($options['featured_products_btn_title'])) : ?>
                                        <div class="read-more">
                                            <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn"><?php echo esc_html( $options['featured_products_btn_title'] ); ?></a>
                                        </div><!-- .read-more -->
                                    <?php endif; ?>
                                </div><!-- .entry-container -->
                            </div><!-- .featured-image -->
                        </article>
                        <?php endforeach; ?>

                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div>

    <?php }
endif;