<?php
/**
 * Banner section
 *
 * This is the template for the content of slider section
 *
 * @package Theme Palace
 * @subpackage  Workart Pro
 * @since  Workart Pro 1.0.0
 */
if ( ! function_exists( 'workart_pro_add_featured_slider_section' ) ) :
    /**
    * Add slider section
    *
    *@since  Workart Pro 1.0.0
    */
    function workart_pro_add_featured_slider_section() {
    	$options = workart_pro_get_theme_options();
        // Check if slider is enabled on frontpage
        $featured_slider_enable = apply_filters( 'workart_pro_section_status', true, 'featured_slider_section_enable' );

        if ( true !== $featured_slider_enable ) {
            return false;
        }
        // Get slider section details
        $section_details = array();
        $section_details = apply_filters( 'workart_pro_filter_featured_slider_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render slider section now.
        workart_pro_render_featured_slider_section( $section_details );
}

endif;

if ( ! function_exists( 'workart_pro_get_featured_slider_section_details' ) ) :
    /**
    * slider section details.
    *
    * @since  Workart Pro 1.0.0
    * @param array $input slider section details.
    */
    function workart_pro_get_featured_slider_section_details( $input ) {
        $options = workart_pro_get_theme_options();

        // Content type.
        $featured_slider_content_type    = $options['featured_slider_content_type'];
        $featured_slider_count           = ! empty( $options['featured_slider_count'] ) ? $options['featured_slider_count'] : 3;
        
        $content = array();
        switch ( $featured_slider_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $featured_slider_count; $i++ ) {
                    if ( ! empty( $options['featured_slider_content_page_' . $i] ) )
                        $page_ids[] = $options['featured_slider_content_page_' . $i];
                }

                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $featured_slider_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $featured_slider_count; $i++ ) {
                    if ( ! empty( $options['featured_slider_content_post_' . $i] ) )
                        $post_ids[] = $options['featured_slider_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'             => 'post',
                    'post__in'              => ( array ) $post_ids,
                    'posts_per_page'        => absint( $featured_slider_count ),
                    'orderby'               => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['featured_slider_category'] ) ? $options['featured_slider_category'] : '';
                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => absint( $featured_slider_count ),
                    'cat'                   => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            $i = 1;
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = workart_pro_trim_content($options['featured_slider_excerpt_length']);
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : '';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
            $i++;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// slider section content details.
add_filter( 'workart_pro_filter_featured_slider_section_details', 'workart_pro_get_featured_slider_section_details' );


if ( ! function_exists( 'workart_pro_render_featured_slider_section' ) ) :
  /**
   * Start slider section
   *
   * @return string slider content
   * @since  Workart Pro 1.0.0
   *
   */
   function workart_pro_render_featured_slider_section( $content_details = array() ) {
        $options = workart_pro_get_theme_options();
        $featured_slider_autoplay_enable = ($options['featured_slider_autoplay_enable']) ? 'true' : 'false';
        $featured_slider_btn_alt_url = (!empty($options['featured_slider_btn_alt_url'])) ? $options['featured_slider_btn_alt_url'] : '';

        if ( empty( $content_details ) ) {
            return;
        } ?>
        
        <div id="workart_pro_featured_slider_section" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1500, "dots": true, "arrows": true, "autoplay": <?php echo esc_attr($featured_slider_autoplay_enable); ?>, "draggable": true, "fade": true }'>
            <?php foreach ( $content_details as $content ) : ?>
                
                <article style="background-image:url('<?php echo esc_url($content['image']); ?>');">
                    <div class="overlay"></div>
                    <div class="wrapper">
                        <div class="featured-content-wrapper">
                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            </header>

                            <div class="entry-content">
                                <p><?php echo wp_kses_post($content['excerpt']); ?></p>
                            </div><!-- .entry-content-->

                            
                            <?php if(!empty($options['featured_slider_btn_txt']) && !empty($options['featured_slider_btn_alt_txt'])): ?>

                                <div class="read-more">
                                    <?php if(!empty($options['featured_slider_btn_txt'])): ?>
                                        <a href="<?php echo esc_url($content['url']); ?>" class="btn"><?php echo esc_html($options['featured_slider_btn_txt']); ?></a>
                                    <?php endif; ?>

                                    <?php if(!empty($options['featured_slider_btn_alt_txt']) && !empty($featured_slider_btn_alt_url)): ?>
                                        <a href="<?php echo esc_url($featured_slider_btn_alt_url); ?>" class="btn"><?php echo esc_html($options['featured_slider_btn_alt_txt']); ?></a>
                                    <?php endif; ?>
                                </div><!-- .read-more -->

                            <?php endif; ?>

                        </div><!-- .featured-content-wrapper -->
                    </div><!-- .wrapper -->
                </article>
            <?php endforeach; ?>

        </div><!-- #workart_pro_featured_slider_section -->
<?php
    }    
endif;