<?php
/**
 * Latest Product section
 *
 * This is the template for the content of latest_products section
 *
 * @package Theme Palace
 * @subpackage Workart Pro
 * @since Workart Pro 1.0.0
 */
if ( ! function_exists( 'workart_pro_add_latest_products_section' ) ) :
    /**
    * Add latest_products section
    *
    *@since Workart Pro 1.0.0
    */
    function workart_pro_add_latest_products_section() {
    	$options = workart_pro_get_theme_options();
        // Check if latest_products is enabled on frontpage
        $latest_products_enable = apply_filters( 'workart_pro_section_status', true, 'latest_products_section_enable' );

        if ( !$latest_products_enable || !class_exists('WooCommerce')) {
            return false;
        }
 
        // Get latest_products section details
        $section_details = array();
        $section_details = apply_filters( 'workart_pro_filter_latest_products_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }

        // Render latest_products section now.
        workart_pro_render_latest_products_section( $section_details );
    }
endif;

if ( ! function_exists( 'workart_pro_get_latest_products_section_details' ) ) :
    /**
    * latest_products section details.
    *
    * @since Workart Pro 1.0.0
    * @param array $input latest_products section details.
    */
    function workart_pro_get_latest_products_section_details( $input ) {
        $options = workart_pro_get_theme_options();

        // Content type.
        $latest_products_content_type  = $options['latest_products_content_type'];
        $latest_products_count = ! empty( $options['latest_products_count'] ) ? $options['latest_products_count'] : 2;
        
        $content = array();
        $args = array();
        switch ( $latest_products_content_type ) {


            case 'product':
                $page_ids = array();

                for ( $i = 1; $i <= $latest_products_count; $i++ ) {
                    if ( ! empty( $options['latest_products_content_product_' . $i] ) )
                        $page_ids[] = $options['latest_products_content_product_' . $i];
                }

                $args = array(
                    'post_type'         => 'product',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $latest_products_count ),
                    'orderby'           => 'post__in',
                );
            break;
            
            case 'product-category':
                $cat_id = ! empty( $options['latest_products_content_product_category'] ) ? $options['latest_products_content_product_category'] : '';

                $args = array(
                'post_type'         => 'product',
                'posts_per_page'    => absint( $latest_products_count ),
                'tax_query'         => array(
                    array(
                        'taxonomy'  => 'product_cat',
                        'field'     => 'id',
                        'terms'     => $cat_id
                    )
                ) );
            break;

            default:
            break;
        }

        for($i=1; $i<=2; $i++){
            $cat_id = ! empty( $options['latest_products_content_product_category_'.$i.''] ) ? $options['latest_products_content_product_category_'.$i.''] : '';
            $term = get_term( $cat_id, 'product_cat' );
            if(!is_wp_error($term)) {
                $page_post['id']        = $term->term_id;
                $page_post['title']     = $term->name;
                $page_post['url']       = get_term_link($term->slug, 'product_cat');
                $page_post['image']  	= (!empty(get_term_meta( $term->term_id, 'thumbnail_id', true ))) ? wp_get_attachment_url( get_term_meta( $term->term_id, 'thumbnail_id', true ) ) : get_template_directory_uri().'/assets/uploads/no-featured-image-600x450.jpg';
                
                // Push to the main array.
                array_push( $content, $page_post );
            }
        }
    
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// latest_products section content details.
add_filter( 'workart_pro_filter_latest_products_section_details', 'workart_pro_get_latest_products_section_details' );


if ( ! function_exists( 'workart_pro_render_latest_products_section' ) ) :
  /**
   * Start latest_products section
   *
   * @return string latest_products content
   * @since Workart Pro 1.0.0
   *
   */
   function workart_pro_render_latest_products_section( $content_details = array() ) {
        $options = workart_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
      
            <div id="workart_pro_latest_products_section" class="relative page-section">
                <div class="wrapper">
                    <div class="col-2 clear">
                    <?php foreach ( $content_details as $content ): ?>

                        <article>
                            <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ) ?>');">
                                <div class="entry-container">
                                    <header class="entry-header">
                                        <h2 class="entry-title"><?php echo esc_html( $content['title'] ) ?></h2>
                                    </header>
                                </div><!-- .entry-container -->
                            </div><!-- .featured-image -->
                        </article>
                        <?php endforeach; ?>

                    </div><!-- .grid --> 
                </div><!-- .wrapper -->
            </div><!-- #workart_pro_latest_products_section -->
    <?php }
endif;
