<?php
/**
 * Banner section
 *
 * This is the template for the content of sponsor section
 *
 * @package Theme Palace
 * @subpackage  Workart Pro
 * @since  Workart Pro 1.0.0
 */
if ( ! function_exists( 'workart_pro_add_our_partners_section' ) ) :
    /**
    * Add sponsor section
    *
    *@since  Workart Pro 1.0.0
    */
    function workart_pro_add_our_partners_section() {
    	$options = workart_pro_get_theme_options();
        // Check if sponsor is enabled on frontpage
        $our_partners_enable = apply_filters( 'workart_pro_section_status', true, 'our_partners_section_enable' );

        if ( true !== $our_partners_enable ) {
            return false;
        }
        // Get sponsor section details
        $section_details = array();
        $section_details = apply_filters( 'workart_pro_filter_our_partners_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render sponsor section now.
        workart_pro_render_our_partners_section( $section_details );
}

endif;

if ( ! function_exists( 'workart_pro_get_our_partners_section_details' ) ) :
    /**
    * sponsor section details.
    *
    * @since  Workart Pro 1.0.0
    * @param array $input sponsor section details.
    */
    function workart_pro_get_our_partners_section_details( $input ) {
        $options = workart_pro_get_theme_options();

        // Content type.
        $our_partners_content_type    = $options['our_partners_content_type'];
        $our_partners_count           = ! empty( $options['our_partners_count'] ) ? $options['our_partners_count'] : 4;
        
        $content = array();
        switch ( $our_partners_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $our_partners_count; $i++ ) {
                    if ( ! empty( $options['our_partners_content_page_' . $i] ) )
                        $page_ids[] = $options['our_partners_content_page_' . $i];
                }

                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $our_partners_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $our_partners_count; $i++ ) {
                    if ( ! empty( $options['our_partners_content_post_' . $i] ) )
                        $post_ids[] = $options['our_partners_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'             => 'post',
                    'post__in'              => ( array ) $post_ids,
                    'posts_per_page'        => absint( $our_partners_count ),
                    'orderby'               => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['our_partners_category'] ) ? $options['our_partners_category'] : '';
                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => absint( $our_partners_count ),
                    'cat'                   => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;
            
            case 'custom':
                for($i=1; $i<=$our_partners_count; $i++){

                    $page_post['image']     = !empty($options['our_partners_image_'.$i])? $options['our_partners_image_'.$i]: get_template_directory_uri().'/assets/uploads/no-featured-image-600x450.jpg';
                    $page_post['url']       = !empty($options['our_partners_url_'.$i])? $options['our_partners_url_'.$i]: '';
                    if(!empty($page_post['url']))
                        array_push( $content, $page_post );
                }
                return $content;
            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            $i = 1;
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'medium' ) : get_template_directory_uri().'/assets/uploads/no-featured-image-600x450.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
            $i++;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// sponsor section content details.
add_filter( 'workart_pro_filter_our_partners_section_details', 'workart_pro_get_our_partners_section_details' );


if ( ! function_exists( 'workart_pro_render_our_partners_section' ) ) :
  /**
   * Start sponsor section
   *
   * @return string sponsor content
   * @since  Workart Pro 1.0.0
   *
   */
   function workart_pro_render_our_partners_section( $content_details = array() ) {
        $options = workart_pro_get_theme_options();
        $our_partners_count           = ! empty( $options['our_partners_count'] ) ? $options['our_partners_count'] : 4;

        if ( empty( $content_details ) ) {
            return;
        } ?>
        
        <div id="workart_pro_our_partners_section" class="relative page-section">
            <div class="wrapper">
                <div class="col-<?php echo esc_attr( $our_partners_count ); ?>">
                    <?php foreach ( $content_details as $content ) : if(empty($content['url'])) continue; ?>
                        <article>
                            <div class="client-logo">
                                <a href="<?php echo esc_url( $content['url'] ); ?>">
                                    <img src="<?php echo esc_url($content['image']); ?>" alt="<?php echo esc_attr($content['title']); ?>">
                                </a>
                            </div>
                        </article>
                    <?php endforeach; ?>
                </div><!-- .col-4 -->
            </div><!-- .wrapper -->
        </div><!-- #workart_pro_our_partners_section -->
    <?php
    }    
endif;

