<?php
/**
 * Product section
 *
 * This is the template for the content of popular_product section
 *
 * @package Theme Palace
 * @subpackage Workart Pro
 * @since Workart Pro 1.0.0
 */
if ( ! function_exists( 'workart_pro_add_popular_products_section' ) ) :
    /**
    * Add popular_products section
    *
    *@since Workart Pro 1.0.0
    */
    function workart_pro_add_popular_products_section() {
    	$options = workart_pro_get_theme_options();
        // Check if popular_products is enabled on frontpage
        $popular_products_enable = apply_filters( 'workart_pro_section_status', true, 'popular_products_section_enable' );

        if ( true !== $popular_products_enable || !class_exists('WooCommerce')) {
            return false;
        }
        // Get popular_products section details
        $section_details = array();
        $section_details = apply_filters( 'workart_pro_filter_popular_products_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }

        // Render popular_products section now.
        workart_pro_render_popular_products_section( $section_details );
    }
endif;

if ( ! function_exists( 'workart_pro_get_popular_products_section_details' ) ) :
    /**
    * popular_products section details.
    *
    * @since Workart Pro 1.0.0
    * @param array $input popular_products section details.
    */
    function workart_pro_get_popular_products_section_details( $input ) {
        $options = workart_pro_get_theme_options();

        // Content type.
        $popular_products_content_type  = $options['popular_products_content_type'];
        $popular_products_count = ! empty( $options['popular_products_count'] ) ? $options['popular_products_count'] : 3;

        $content = array();
        switch ( $popular_products_content_type ) {

            case 'product':
                $page_ids = array();

                for ( $i = 1; $i <= $popular_products_count; $i++ ) {
                    if ( ! empty( $options['popular_products_content_product_' . $i] ) )
                        $page_ids[] = $options['popular_products_content_product_' . $i];
                }

                $args = array(
                    'post_type'         => 'product',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $popular_products_count ),
                    'orderby'           => 'post__in',
                );

            break;

            case 'product-category':
                $cat_id = ! empty( $options['popular_products_category'] ) ? $options['popular_products_category'] : '';

                $args = array(
                    'post_type'         => 'product',
                    'posts_per_page'    => absint( $popular_products_count ),
                    'tax_query'         => array(
                        array(
                            'taxonomy'  => 'product_cat',
                            'field'     => 'id',
                            'terms'     => $cat_id
                        )
                    )
                );

            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = workart_pro_trim_content( 20 );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'medium_large' ) : get_template_directory_uri().'/assets/uploads/no-featured-image-600x450.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();
    
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// popular_products section content details.
add_filter( 'workart_pro_filter_popular_products_section_details', 'workart_pro_get_popular_products_section_details' );


if ( ! function_exists( 'workart_pro_render_popular_products_section' ) ) :
  /**
   * Start popular_products section
   *
   * @return string popular_products content
   * @since Workart Pro 1.0.0
   *
   */
   function workart_pro_render_popular_products_section( $content_details = array() ) {
        $options = workart_pro_get_theme_options();
        $popular_products_content_type  = $options['popular_products_content_type'];

        if ( empty( $content_details ) ) {
            return;
        }  ?>

            <div id="workart_pro_popular_products_section" class="relative page-section same-background">
                <div class="wrapper">
                    <div class="section-header">
                        <p class="section-subtitle"><?php echo esc_html( $options['popular_products_sub_title'] ); ?></p>
                        <h2 class="section-title"><?php echo esc_html( $options['popular_products_title'] ); ?></h2>
                    </div><!-- .section-header -->

                    <div class="section-content">
                        <ul class="products columns-3 product-slider">
                        <?php foreach ( $content_details as $i=>$content ): $product = new WC_Product( $content['id'] );  ?>
                            
                            <li class="product first sale featured-products">
                                <a href="#" class="woocommerce-LoopProduct-link woocommerce-loop-product__link">
                                    <?php if ( $product->get_sale_price() ) echo '<span class="onsale">'. esc_html__('Sale!', 'workart-pro'). '</span>'; ?>
                                    <img width="330" height="400" src="<?php echo esc_url( $content['image'] ); ?>">
                                </a>
                                    <div class="product_meta"><a href="<?php echo esc_url( $content['image'] ) ?>" class="woocommerce-LoopProduct-link woocommerce-loop-product__link">
                                        <span class="posted_in"></span><!-- .posted_in -->
                                    </div><!-- .product-meta -->
                                    <h2 class="woocommerce-loop-product__title"><?php echo esc_html( $content['title'] ); ?></h2>

                                    <span class="price"><?php echo $product->get_price_html(); ?></span>
                                
                                <a href="<?php echo esc_url( $content['url'] ) ?>" class="button product_type_simple add_to_cart_button ajax_add_to_cart">Add to cart</a>
                            </li>

                        <?php endforeach; ?>

                        </ul><!-- .product-slider -->
                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div>
    <?php }
endif;     