<?php
/**
 * Product Collection section
 *
 * This is the template for the content of products_collection section
 *
 * @package Theme Palace
 * @subpackage Workart Pro
 * @since Workart Pro 1.0.0
 */
if ( ! function_exists( 'workart_pro_add_products_collection_section' ) ) :
    /**
    * Add products_collection section
    *
    *@since Workart Pro 1.0.0
    */
    function workart_pro_add_products_collection_section() {
    	$options = workart_pro_get_theme_options();
        // Check if products_collection is enabled on frontpage
        $products_collection_enable = apply_filters( 'workart_pro_section_status', true, 'products_collection_section_enable' );

        if ( true !== $products_collection_enable || !class_exists('WooCommerce') ) {
            return false;
        }
  
        // Get products_collection section details
        $section_details = array();
        $section_details = apply_filters( 'workart_pro_filter_products_collection_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render products_collection section now.
        workart_pro_render_products_collection_section( $section_details );
    }
endif;

if ( ! function_exists( 'workart_pro_get_products_collection_section_details' ) ) :
    /**
    * products_collection section details.
    *
    * @since Workart Pro 1.0.0
    * @param array $input products_collection section details.
    */
    function workart_pro_get_products_collection_section_details( $input ) {
        $options = workart_pro_get_theme_options();

        // Content type.
        $products_collection_content_type  = $options['products_collection_content_type'];
        $products_collection_count = ! empty( $options['products_collection_count'] ) ? $options['products_collection_count'] : 4;
    
        $content = array();
        switch ( $products_collection_content_type ) {


            case 'product':
                $page_ids = array();

                for ( $i = 1; $i <= $products_collection_count; $i++ ) {
                    if ( ! empty( $options['products_collection_content_product_' . $i] ) )
                        $page_ids[] = $options['products_collection_content_product_' . $i];
                }

                $args = array(
                    'post_type'         => 'product',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $products_collection_count ),
                    'orderby'           => 'post__in',
                    );
            break;

            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $products_collection_count; $i++ ) {
                    if ( ! empty( $options['products_collection_content_page_' . $i] ) )
                        $page_ids[] = $options['products_collection_content_page_' . $i];
                }
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $products_collection_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $products_collection_count; $i++ ) {
                    if ( ! empty( $options['products_collection_content_post_' . $i] ) )
                        $post_ids[] = $options['products_collection_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'             => 'post',
                    'post__in'              => ( array ) $post_ids,
                    'posts_per_page'        => absint( $products_collection_count ),
                    'orderby'               => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'product-category':
                $cat_id = ! empty( $options['products_collection_content_product_category'] ) ? $options['products_collection_content_product_category'] : '';

                $args = array(
                'post_type'         => 'product',
                'posts_per_page'    => absint( $products_collection_count ),
                'tax_query'         => array(
                    array(
                        'taxonomy'  => 'product_cat',
                        'field'     => 'id',
                        'terms'     => $cat_id
                    )
                ) );
            break;

            default:
                $args = array(
                    'post_type'             => 'post',
                    'ignore_sticky_posts'   => true,
                    );
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = workart_pro_trim_content( 20 );
                $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'medium_large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// products_collection section content details.
add_filter( 'workart_pro_filter_products_collection_section_details', 'workart_pro_get_products_collection_section_details' );


if ( ! function_exists( 'workart_pro_render_products_collection_section' ) ) :
  /**
   * Start products_collection section
   *
   * @return string products_collection content
   * @since Workart Pro 1.0.0
   *
   */
   function workart_pro_render_products_collection_section( $content_details = array() ) {
        $options = workart_pro_get_theme_options();
        $products_collection_content_type  = $options['products_collection_content_type'];
        
        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="workart_pro_products_collection_section" class="relative page-section">
            <div class="wrapper">
                <div class="section-header">
                    <p class="section-subtitle"><?php echo esc_html( $options['products_collection_subtitle'] ); ?></p>    
                    <h2 class="section-title"><?php echo esc_html( $options['products_collection_title'] ); ?></h2>
                </div><!-- .section-header -->
                
                <div class="section-content grid col-2">
                    
                <?php foreach ( $content_details as $content ): ?>
                    <article class="grid-item">
                        <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                            <div class="entry-container">
                                <span class="cat-links">
                                    <ul class="post-categories">
                                        <?php echo (in_array($products_collection_content_type, array('product', 'product-category')) && class_exists('WooCommerce') ) ? wc_get_product_category_list($content['id']) :  the_category( ', ', '', $content['id'] ); ?>
                                    </ul>
                                </span><!-- .cat-links -->

                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url($content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>

                                <?php if ( !empty( $options['products_collection_btn_title'] )): ?>
                                    <div class="read-more">
                                        <a href="<?php echo $content['url']; ?>" class="btn"><?php echo esc_html( $options['products_collection_btn_title'] ); ?></a>
                                    </div><!-- .read-more -->
                                <?php endif; ?>

                            </div><!-- .entry-container -->
                        </div><!-- .featured-image -->
                    </article>
                <?php endforeach; ?>

                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div><!-- #workart_pro_products_collection_section -->

    <?php }
endif;
