<?php
/**
 * trending_products section
 *
 * This is the template for the content of trending_products section
 *
 * @package Theme Palace
 * @subpackage Workart Pro
 * @since Workart Pro 1.0.0
 */
if ( ! function_exists( 'workart_pro_add_trending_products_section' ) ) :
    /**
    * Add trending_products section
    *
    *@since Workart Pro 1.0.0
    */
    function workart_pro_add_trending_products_section() {
    	$options = workart_pro_get_theme_options();
        
        // Check if trending_products is enabled on frontpage
        $trending_products_enable = apply_filters( 'workart_pro_section_status', true, 'trending_products_section_enable' );

        if ( true !== $trending_products_enable || ! class_exists( 'WooCommerce' ) ){
            return false;
        }

        // Get trending_products section details
        $section_details = array();
        $section_details = apply_filters( 'workart_pro_filter_trending_products_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render trending_products section now.
        workart_pro_render_trending_products_section( $section_details );
    }
endif;

if ( ! function_exists( 'workart_pro_get_trending_products_section_details' ) ) :
    /**
    * trending_products section details.
    *
    * @since Workart Pro 1.0.0
    * @param array $input trending_products section details.
    */
    function workart_pro_get_trending_products_section_details( $input ) {
        $options = workart_pro_get_theme_options();
        $content = array();
        $content[1] = array();
        $content[2] = array();
        $content[3] = array();

        for ($i=1; $i <= 3 ; $i++) { 
                // Content type.

            $trending_products_content_type  = !empty( $options['trending_products_content_type_'.$i] ) ?  $options['trending_products_content_type_'.$i]  : $options['trending_products_content_type'];
            $trending_products_count = ! empty( $options['trending_products_count'] ) ? $options['trending_products_count'] : 4;
        
            switch ( $trending_products_content_type ) {
                
                case 'recent_product':
                    $args = array(
                        'post_type'             => 'product',
                        'posts_per_page'        => absint($trending_products_count),
                        'ignore_sticky_posts'   => true,
                        );
                break;

                case 'product':
                    $products = array();

                    for ( $j = 1; $j <=  absint($trending_products_count); $j++ ){
                        if ( ! empty( $options['trending_products_content_product_' . $i.$j] ) ){
                            $products[] = $options['trending_products_content_product_' . $i.$j];
                        }
                        
                    }
                      
                    $args = array(
                        'post_type'         => 'product',
                        'post__in'          => ( array ) $products,
                        'posts_per_page'    => absint($trending_products_count),
                        'orderby'           => 'post__in',
                        );
                break;

                case 'product-category':
                    $product_cat_id = ! empty( $options['trending_products_content_product_category_'.$i] ) ? $options['trending_products_content_product_category_'.$i] : '';

                    $args = array(
                    'post_type'         => 'product',
                    'posts_per_page'    => absint( $trending_products_count ),
                    'tax_query'         => array(
                        array(
                            'taxonomy'  => 'product_cat',
                            'field'     => 'id',
                            'terms'     => $product_cat_id
                        )
                    ) );
                break;

                default:
                break;
            }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['excerpt']   = workart_pro_trim_content( 30 );
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'medium' ) : get_template_directory_uri().'/assets/uploads/no-featured-image-600x450.jpg';

                    // Push to the main array.
                    array_push( $content[$i], $page_post );
               
                endwhile;
            endif;
            wp_reset_postdata();
        }
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// trending_products section content details.
add_filter( 'workart_pro_filter_trending_products_section_details', 'workart_pro_get_trending_products_section_details' );


if ( ! function_exists( 'workart_pro_render_trending_products_section' ) ) :
  /**
   * Start trending_products section
   *
   * @return string trending_products content
   * @since Workart Pro 1.0.0
   *
   */
   function workart_pro_render_trending_products_section( $content_details = array() ) {
        $options = workart_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
  
        <div id="workart_pro_trending_products_section" class="relative page-section">
            <div class="wrapper">
                <div class="section-content clear">
                <?php for ( $i=1; $i <=3 ; $i++) : ?>

                    <div class="product-wrapper">
                        <h2 class="category-title <?php echo esc_attr( $i ); ?>"><?php echo esc_html( isset($options['trending_products_title_'.$i]) ? $options['trending_products_title_'.$i] : $options['trending_products_title'] ) ; ?></h2>
                        <div class="product-items">
                        <?php foreach ($content_details[$i] as $content): ?>

                            <article>
                                <div class="featured-image">
                                    <a href="<?php echo esc_url($content['url']); ?>"><img src="<?php echo esc_url(  $content['image'] );?>" title="<?php echo esc_attr($content['title']); ?>"></a>
                                </div><!-- .featured-image -->

                                <div class="entry-container">
                                    <!-- <span class="discount-offer">-30%</span> -->
                                    <span class="cat-links">
                                        <ul class="post-categories">
                                        <?php 
                                            $terms = get_the_terms ( $content['id'], 'product_cat' );
                                            foreach ( $terms as $term ) { ?>
                                                <li class="posted_in">
                                                    <a href="<?php echo esc_url( get_term_link( $term->term_id, 'product_cat' ) ) ?>"><?php echo esc_html( $term->name) ; ?></a>
                                                </li><!-- .posted_in -->
                                        <?php } ?>
                                        </ul>
                                    </span><!-- .cat-links -->

                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ) ; ?>"><?php echo esc_html( $content['title'] ) ; ?></a></h2>
                                    </header>

                                    <span class="price">
                                        <?php $product = new WC_Product( $content['id'] ); echo $product->get_price_html(); ?>
                                    </span><!-- .price -->
                                </div><!-- .entry-container -->
                            </article>
                            <?php endforeach ?>

                        </div><!-- .product-items -->
                    </div><!-- .product-wrapper -->

                <?php endfor; ?>                    

                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div><!-- #workart_pro_trending_products_section -->
    <?php }
endif;
